#!/usr/bin/ksh
#
# Xerox DocuPrint N2025
# Advanced Printing self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Xerox DocuPrint N2025"
KIT_FILES="Xerox_DocuPrintN2025_PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-001" /usr/pd/share/cap/Xerox_DocuPrintN2025_PS.paf 24699 3)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Xerox_DocuPrintN2025_PS.paf
M(R!0<FEN=&5R($%T=')I8G5T92!&:6QE(&9O<B!897)O>"!$;V-U4')I;G0@
M3C(P,C4@<')I;G1E<@HC(%)E=BX@,#<M36%Y+3(P,#$*(PHC($-O<'ER:6=H
M="`R,#`Q($-O;7!A<2!#;VUP=71E<B!#;W)P;W)A=&EO;BX@06QL(%)I9VAT
M<R!297-E<G9E9"X*(PHC($1O8W50<FEN="!I<R!A('1R861E;6%R:R!O9B!8
M97)O>"!#;W)P;W)A=&EO;BX*(R!0;W-T4V-R:7!T(&ES(&$@=')A9&5M87)K
M(&]F($%D;V)E(%-Y<W1E;7,@26YC;W)P;W)A=&5D+@H*<&%F+7@M9FEL92UN
M86UE/2)897)O>%]$;V-U4')I;G1.,C`R-5]04RYP868B"G!A9BUX+69I;&4M
M=F5R<VEO;CTB05!8+3$M,#`Q(@H*<')I;G1E<BUM;V1E;#TB6&5R;W@@1&]C
M=5!R:6YT($XR,#(U(%!3(@IM87AI;75M+7!R:6YT97(M<W!E960],C`*"FYA
M=&EV92UD;V-U;65N="UF;W)M871S+7)E861Y/2)0;W-T4V-R:7!T(@ID;V-U
M;65N="UF;W)M871S+7-U<'!O<G1E9#TB4&]S=%-C<FEP="(@(G-I;7!L92UT
M97AT(@ID;V-U;65N="UF;W)M871S+7)E861Y/2)0;W-T4V-R:7!T(B`B<VEM
M<&QE+71E>'0B"@IP;&5X97,M<W5P<&]R=&5D/2)S:6UP;&5X(@IS:61E<RUS
M=7!P;W)T960](C$B"G-I9&5S+7)E861Y/2(Q(@H*:6YP=70M=')A>7,M<W5P
M<&]R=&5D/2)T;W`B(")M86EN(@II;G!U="UT<F%Y<RUR96%D>3TB=&]P(B`B
M;6%I;B(*"B,@4W5P97)V:7-O<B!H:6YT<PH*<&%F+6ES+7!J;#UF86QS90IP
M868M;F%T:79E+61O8W5M96YT+69O<FUA="TQ/2)0;W-T4V-R:7!T(@IP868M
M9&5F875L="UD;V-U;65N="UF;W)M870](E!O<W138W)I<'0B"G!A9BUJ;V(M
M<V5P87)A=&]R+69O<FUA=#TB4&]S=%-C<FEP="(*"B,@8V]N;F5C=&EO;BUR
M96QA=&5D(&%T=')I8G5T97,*"G!A9BUC;VYN96-T:6]N+6QE=F5L+7!A<F%L
M;&5L/3(*<&%F+6-O;FYE8W1I;VXM;&5V96PM:7`M<V]C:V5T/3,*<')I;G1E
M<BUT8W!I<"UP;W)T+6YU;6)E<CTY,3`P"@HC(%!$3"UD97!E;F1E;G0@8V]M
M;6%N9',*"B,@26YP=70@=')A>2!S96QE8W1I;VX*(PHC(%1H92!04R!,979E
M;"`Q('-E='!A<&5R=')A>2!C;VUM86YD('=I;&P@<V5L96-T(&$@=')A>2!R
M96=A<F1L97-S(&]F('1H90HC(&EN<W1A;&QE9"!P87!E<B`H;65D:6$I('-I
M>F4N(%1H:7,@9V5T<R!A<F]U;F0@=&AE('1R87D@<V5L96-T('!O;&EC:65S
M+@HC"B,@3F]T97,*(PDM(%1H92!M=6QT:2UP=7)P;W-E('1R87D@:7,@:&%N
M9&QE9"!A<R!A(&-A<W-E='1E('1R87DN"B,)+2!4:&4@<')I;G1E<B!W:6QL
M('=A:70@;VX@96UP='D@8V%S971T92!T<F%Y+@HC"2T@4')I;G1E<B!W:6QL
M('!R:6YT('=H96X@;F]N+65X:7-T:6YG('1R87D@:7,@<V5L96-T960N"B,*
M(PDM(%1O<"!I<R!N;W0@=')A>2`C,2!B96-A=7-E('1H92!P<FEN=&5R(&1I
M<W!L87ES('1H92!S96QE8W1E9`HC"2`@=')A>2!N=6UB97(N($ET)W,@;&5S
M<R!C;VYF=7-I;F<@=&\@:V5E<"!T:&4@<&AY<VEC86P@=')A>2!N=6UB97(*
M(PD@(&%N9"!T:&4@<V]F="!S96QE8W0@=')A>2!N=6UB97)S('1H92!S86UE
M+B`*(PHC($1E=FEC92!T<F%Y(&YA;64@("`@("`@("`@($])1"!T<F%Y(&YA
M;64@("!4<F%Y($YU;6)E<B`@("!3=&%N9&%R9"]/<'1I;VYA;`HC("TM+2TM
M+2TM+2TM+2TM+2T@("`@("`@("`@("TM+2TM+2TM+2TM+2T@("`M+2TM+2TM
M+2TM+2`@("`M+2TM+2TM+2TM+2TM+2TM+0HC($UU;'1I+7!U<G!O<V4@("`@
M("`@("`@("`@('1O<"`@("`@("`@("`@("`@("`@("`M("`@("`@("!3=&%N
M9&%R9`HC(%1R87D@,2`@("`@("`@("`@("`@("`@("`@(&UA:6X@("`@("`@
M("`@("`@("`@("`Q("`@("`@("!3=&%N9&%R9`HC(%1R87D@,B`@("`@("`@
M("`@("`@("`@("`@(&UI9&1L92`@("`@("`@("`@("`@("`R("`@("`@("!/
M<'1I;VYA;`HC(%1R87D@,R`@("`@("`@("`@("`@("`@("`@(&)O='1O;2`@
M("`@("`@("`@("`@("`S("`@("`@("!/<'1I;VYA;`H*(R!P868M:6YP=70M
M=')A>7,M<&]S<VEB;&4*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C@S/2)T
M;W`@;6%I;B!M:61D;&4@8F]T=&]M(#$@,B`S(@H*(R!P868M:6YP=70M=')A
M>2UA;&EA<V5S"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XT,CTB,3IM86EN
M(#(Z;6ED9&QE(#,Z8F]T=&]M(@H*(R!.=6UB97)E9"!T<F%Y(&YA;65S(&%R
M92!S=7!P;W)T960@:6X@<&1S<'9R(%8Q+C$@86YD(&QA=&5R"@IP868M=&]P
M+6EN<'5T+6-O;6UA;F0M,3TB('-T871U<V1I8W0@8F5G:6X@>R`Q('-E='!A
M<&5R=')A>2!]('-T;W!P960@96YD('!O<"`B"G!A9BUM86EN+6EN<'5T+6-O
M;6UA;F0M,3TB('-T871U<V1I8W0@8F5G:6X@>R`P('-E='!A<&5R=')A>2!]
M('-T;W!P960@96YD('!O<"`B"G!A9BUM:61D;&4M:6YP=70M8V]M;6%N9"TQ
M/2(@<W1A='5S9&EC="!B96=I;B![(#(@<V5T<&%P97)T<F%Y('T@<W1O<'!E
M9"!E;F0@<&]P("(*<&%F+6)O='1O;2UI;G!U="UC;VUM86YD+3$](B!S=&%T
M=7-D:6-T(&)E9VEN('L@,R!S971P87!E<G1R87D@?2!S=&]P<&5D(&5N9"!P
M;W`@(@H*(R!3:61E<R!S96QE8W1I;VX*"G!A9BUS970M<VEM<&QE>"UC;VUM
M86YD+3$](B`\/"]$=7!L97@@9F%L<V4@+U1U;6)L92!F86QS93X^('-E='!A
M9V5D979I8V4@(@IP868M<V5T+61U<&QE>"UC;VUM86YD+3$](B`\/"]$=7!L
M97@@=')U92`O5'5M8FQE(&9A;'-E/CX@<V5T<&%G961E=FEC92`B"G!A9BUS
M970M='5M8FQE+6-O;6UA;F0M,3TB(#P\+T1U<&QE>"!T<G5E("]4=6UB;&4@
>=')U93X^('-E='!A9V5D979I8V4@(@H*(R!%;F0*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Xerox_DocuPrintN2025_PS.paf 24699 3
fi

exit 0
