#!/usr/bin/ksh
#
# Xerox DocuPrint N24
# Advanced Printing self-extracting installation script.
# Updated on 21-Dec-2000
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Xerox DocuPrint N24"
KIT_FILES="Xerox_DocuPrintN24_Level2PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-004" /usr/pd/share/cap/Xerox_DocuPrintN24_Level2PS.paf 31803 7)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Xerox_DocuPrintN24_Level2PS.paf
M(R!0<FEN=&5R($%T=')I8G5T92!&:6QE(&9O<B!897)O>"!$;V-U4')I;G0@
M3C(T+S,R+S0P('!R:6YT97(*(R!2978N(#4M1&5C+3(P,#$*(PHC($-O<'ER
M:6=H="`Q.3DX+3(P,#$@0V]M<&%Q($-O;7!U=&5R($-O<G!O<F%T:6]N+B`@
M06QL(%)I9VAT<R!297-E<G9E9"X*(PHC(%!O<W138W)I<'0@:7,@82!T<F%D
M96UA<FL@;V8@061O8F4@4WES=&5M<R!);F-O<G!O<F%T960L('=H:6-H(`HC
M(&UA>2!B92!R96=I<W1E<F5D(&EN(&-E<G1A:6X@:G5R:7-D:6-T:6]N<RX@
M(`H*<&%F+7@M9FEL92UN86UE/5AE<F]X7T1O8W50<FEN=$XR-%],979E;#)0
M4RYP868*<&%F+7@M9FEL92UV97)S:6]N/4%06"TQ+3`P-`H*<')I;G1E<BUM
M;V1E;#TB6&5R;W@@1&]C=5!R:6YT($XR-"(*<')I;G1E<BUT8W!I<"UP;W)T
M+6YU;6)E<CTR,#`P"FUA>&EM=6TM<')I;G1E<BUS<&5E9#TR-`H*9&]C=6UE
M;G0M9F]R;6%T<RUS=7!P;W)T960]4&]S=%-C<FEP="!S:6UP;&4M=&5X=`IP
M;&5X97,M<W5P<&]R=&5D/7-I;7!L97@*<VED97,M<W5P<&]R=&5D/3$*:6YP
M=70M=')A>7,M<W5P<&]R=&5D/71O<"!M86EN('-I9&4@;6%N=6%L"F]U='!U
M="UB:6YS+7-U<'!O<G1E9#UT;W`@<VED92!F86-E+75P"@ID;V-U;65N="UF
M;W)M871S+7)E861Y/5!O<W138W)I<'0@<VEM<&QE+71E>'0*;F%T:79E+61O
M8W5M96YT+69O<FUA=',M<F5A9'D]4&]S=%-C<FEP=`IS:61E<RUR96%D>3TQ
M"FEN<'5T+71R87ES+7)E861Y/71O<"!M86EN('-I9&4@;6%N=6%L"F]U='!U
M="UB:6YS+7)E861Y/71O<"!S:61E(&9A8V4M=7`*"B,@<')I=F%T92!S=7!E
M<G9I<V]R(&%T=')I8G5T97,*"G!A9BUI<RUP:FP]=')U90IP868M;F%T:79E
M+61O8W5M96YT+69O<FUA="TQ/5!O<W138W)I<'0*<&%F+61E9F%U;'0M9&]C
M=6UE;G0M9F]R;6%T/5!O<W138W)I<'0*<&%F+6IO8BUS97!A<F%T;W(M9F]R
M;6%T/5!O<W138W)I<'0*<&%F+7-T87)T+7!D;"TQ+6-O;6UA;F0](EQ<,#$R
M)2%<7#`Q,B(*"B,@8V]N;F5C=&EO;BUR96QA=&5D(&%T=')I8G5T97,*"G!A
M9BUC;VYN96-T:6]N+6QE=F5L+7-E<FEA;#TS"G!A9BUC;VYN96-T:6]N+6QE
M=F5L+7!A<F%L;&5L/3(*<&%F+6-O;FYE8W1I;VXM;&5V96PM:7`M<V]C:V5T
M/3,*"B,@365D:6$@<V5L96-T:6]N"B`*(R!0868@071T<FEB=71E("`@("`@
M("`@3TE$($YU;6)E<B`@("`@("`@("`@("`@("`@("`@06QI87,@3F%M92AS
M*2`*(R`M+2TM+2TM+2TM+2TM+2TM+2TM("`@+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2`@7U]?7U]?7U]?7U]?7PHC('!A9BTQ+6UE9&EA+6-O;6UA
M;F0@("`Q+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N.34@("!,971T97(L($$*
M(R!P868M,BUM961I82UC;VUM86YD("`@,2XR+C@T,"XQ,3,U-3`N,2XS+C(N
M,3(P+CDW("`@3&5D9V5R+"!""B,@<&%F+3,M;65D:6$M8V]M;6%N9"`@(#$N
M,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XY.2`@($$S"B,@<&%F+30M;65D:6$M
M8V]M;6%N9"`@(#$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XQ,#$@($$T"@HQ
M+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N.34](B`\/"`O4&%G95-I>F4@6S8Q
M,B`W.3)=("`O26UA9VEN9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E("(*
M,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+CDW/2(@/#P@+U!A9V53:7IE(%LW
M.3(@,3(R-%T@+TEM86=I;F="0F]X(&YU;&P@/CX@<V5T<&%G961E=FEC92`B
M"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XY.3TB(#P\("]086=E4VEZ92!;
M.#0R(#$Q.3%=("]);6%G:6YG0D)O>"!N=6QL(#X^('-E='!A9V5D979I8V4@
M(@HQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N,3`Q/2(@/#P@+U!A9V53:7IE
M(%LU.34@.#0R72`O26UA9VEN9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E
M("(*"B,@<&%F+6UE9&EA+6%L:6%S97,*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N
M,3(P+C<Y/2)L971T97(Z,2!A.C$@;&5D9V5R.C(@8CHR(&$S.C,@830Z-"(*
M"B,@26YP=70@=')A>2!S96QE8W1I;VX@8V]M;6%N9',*(PHC($1E=FEC92!T
M<F%Y(&YA;64@($UE9&EA4&]S:71I;VX@("!$4$$@36%P<&5D(&YA;64@(%-T
M9"]/<'1I;VX*(R`M+2TM+2TM+2TM+2TM+2TM("`M+2TM+2TM+2TM+2TM("`@
M+2TM+2TM+2TM+2TM+2TM("`M+2TM+2TM+2TM"B,@5')A>2`Q("`@("`@("`@
M("`@("`@("`H,"D@("`@("`@('1O<"`@("`@("`@("`@("`@<W1A;F1A<F0*
M(R!4<F%Y(#(@("`@("`@("`@("`@("`@("@Q*2`@("`@("`@;6%I;B`@("`@
M("`@("`@("!S=&%N9&%R9`HC(%1R87D@,R`@("`@("`@("`@("`@("`@*#(I
M("`@("`@("!M:61D;&4@("`@("`@("`@(&]P=&EO;@HC(%1R87D@-"`@("`@
M("`@("`@("`@("`@*#,I("`@("`@("!L87)G92UC87!A8VET>2`@(&]P=&EO
M;@HC(%1R87D@-2`@("`@("`@("`@("`@("`@*#0I("`@("`@("!B;W1T;VT@
M("`@("`@("`@(&]P=&EO;@HC($U"1B`@("`@("`@("`@("`@("`@("`@*#4I
M("`@("`@("!S:61E("`@("`@("`@("`@('-T86YD87)D"B,@16YV96QO<&4@
M("`@("`@("`@("`@("`H-BD@("`@("`@(&5N=F5L;W!E("`@("`@("`@;W!T
M:6]N"B,@36%N=6%L($9E960@("`@("`@("`@("`@+2`@("`@("`@(&UA;G5A
M;"`@("`@("`@("`@<W1A;F1A<F0*"B,@<&%F+6EN<'5T+71R87ES+7!O<W-I
M8FQE"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XX,STB=&]P(&UA:6X@;6ED
M9&QE(&UA;G5A;"!L87)G92UC87!A8VET>2!B;W1T;VT@<VED92!E;G9E;&]P
M92`Q(#(@,R`T(#4B"@HC('!A9BUI;G!U="UT<F%Y+6%L:6%S97,*,2XR+C@T
M,"XQ,3,U-3`N,2XS+C(N,3(P+C0R/2(Q.G1O<"`R.FUA:6X@,SIM:61D;&4@
M-#IL87)G92UC87!A8VET>2`U.F)O='1O;2(*"G!A9BUT;W`M:6YP=70M8V]M
M;6%N9"TQ/2(@,"!S=&%T=7-D:6-T("]S971P87!E<G1R87D@9V5T(&5X96,@
M(@IP868M;6%I;BUI;G!U="UC;VUM86YD+3$](B`Q('-T871U<V1I8W0@+W-E
M='!A<&5R=')A>2!G970@97AE8R`B"G!A9BUM:61D;&4M:6YP=70M8V]M;6%N
M9"TQ/2(@,B!S=&%T=7-D:6-T("]S971P87!E<G1R87D@9V5T(&5X96,@(@IP
M868M;&%R9V4M8V%P86-I='DM:6YP=70M8V]M;6%N9"TQ/2(@,R!S=&%T=7-D
M:6-T("]S971P87!E<G1R87D@9V5T(&5X96,@(@IP868M8F]T=&]M+6EN<'5T
M+6-O;6UA;F0M,3TB(#0@<W1A='5S9&EC="`O<V5T<&%P97)T<F%Y(&=E="!E
M>&5C("(*<&%F+7-I9&4M:6YP=70M8V]M;6%N9"TQ/2(@-2!S=&%T=7-D:6-T
M("]S971P87!E<G1R87D@9V5T(&5X96,@(@IP868M96YV96QO<&4M:6YP=70M
M8V]M;6%N9"TQ/2(@-B!S=&%T=7-D:6-T("]S971P87!E<G1R87D@9V5T(&5X
M96,@(@IP868M;6%N=6%L+6EN<'5T+6-O;6UA;F0M,3TB('-T871U<V1I8W0@
M+VUA;G5A;&9E960@=')U92!P=70@(@H*(R!/=71P=70@8FEN('-E;&5C=&EO
M;B!C;VUM86YD<PH@"B,@<&%F+6]U='!U="UB:6YS+7!O<W-I8FQE"C$N,BXX
M-#`N,3$S-34P+C$N,RXR+C$R,"XX-#TB=&]P('-I9&4@9F%C92UU<"!L87)G
M92!S=&%C:V5R+3$@<W1A8VME<BTR('-T86-K97(M,R`Q(#(@,R`T(#4@-B`W
M(#@@.2`Q,"!M86EL8F]X+3$@;6%I;&)O>"TR(&UA:6QB;W@M,R!M86EL8F]X
M+30@;6%I;&)O>"TU(&UA:6QB;W@M-B!M86EL8F]X+3<@;6%I;&)O>"TX(&UA
M:6QB;W@M.2!M86EL8F]X+3$P(@H*(R!P868M;W5T<'5T+6)I;BUA;&EA<V5S
M"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XT,STB,3IM86EL8F]X+3$@,CIM
M86EL8F]X+3(@,SIM86EL8F]X+3,@-#IM86EL8F]X+30@-3IM86EL8F]X+34@
M-CIM86EL8F]X+38@-SIM86EL8F]X+3<@.#IM86EL8F]X+3@@.3IM86EL8F]X
M+3D@,3`Z;6%I;&)O>"TQ,"(*"G!A9BUT;W`M;W5T<'5T+6-O;6UA;F0M,3TB
M(#P\+T]U='!U=%1Y<&4@*$9!0T4@1$]73B!44D%9*3X^('-E='!A9V5D979I
M8V4@(@IP868M<VED92UO=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP
M92`H1D%#12!54"!44D%9*3X^('-E='!A9V5D979I8V4@(@IP868M9F%C92UU
M<"UO=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H1D%#12!54"!4
M4D%9*3X^('-E='!A9V5D979I8V4@(@IP868M;&%R9V4M;W5T<'5T+6-O;6UA
M;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$9)3DE32$52($))3B`Q*3X^('-E='!A
M9V5D979I8V4@(@H*(R!-86EL8F]X97,@86YD('-T86-K97)S(&%R92!S=7!P
M;W)T960@8GD@=&AE(%8Q+C$@<W5P97)V:7-O<@H*<&%F+6UA:6QB;W@M,2UO
M=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@
M,2D^/B!S971P86=E9&5V:6-E("(*<&%F+6UA:6QB;W@M,BUO=71P=70M8V]M
M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@,BD^/B!S971P
M86=E9&5V:6-E("(*<&%F+6UA:6QB;W@M,RUO=71P=70M8V]M;6%N9"TQ/2(@
M/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@,RD^/B!S971P86=E9&5V:6-E
M("(*<&%F+6UA:6QB;W@M-"UO=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T
M5'EP92`H34%)3$)/6"!"24X@-"D^/B!S971P86=E9&5V:6-E("(*<&%F+6UA
M:6QB;W@M-2UO=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H34%)
M3$)/6"!"24X@-2D^/B!S971P86=E9&5V:6-E("(*<&%F+6UA:6QB;W@M-BUO
M=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@
M-BD^/B!S971P86=E9&5V:6-E("(*<&%F+6UA:6QB;W@M-RUO=71P=70M8V]M
M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@-RD^/B!S971P
M86=E9&5V:6-E("(*<&%F+6UA:6QB;W@M."UO=71P=70M8V]M;6%N9"TQ/2(@
M/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@."D^/B!S971P86=E9&5V:6-E
M("(*<&%F+6UA:6QB;W@M.2UO=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T
M5'EP92`H34%)3$)/6"!"24X@.2D^/B!S971P86=E9&5V:6-E("(*<&%F+6UA
M:6QB;W@M,3`M;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$U!
M24Q"3U@@0DE.(#$P*3X^('-E='!A9V5D979I8V4@(@H*<&%F+7-T86-K97(M
M,2UO=71P=70M8V]M;6%N9"TQ/2(@/#PO3W5T<'5T5'EP92`H1DE.25-(15(@
M0DE.(#$I/CX@<V5T<&%G961E=FEC92`B"G!A9BUS=&%C:V5R+3(M;W5T<'5T
M+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$9)3DE32$52($))3B`R*3X^
M('-E='!A9V5D979I8V4@(@IP868M<W1A8VME<BTS+6]U='!U="UC;VUM86YD
M+3$](B`\/"]/=71P=714>7!E("A&24Y)4TA%4B!"24X@,RD^/B!S971P86=E
M9&5V:6-E("(*"B,@4VED97,@<V5L96-T:6]N(&-O;6UA;F1S"B`*<&%F+7-E
M="US:6UP;&5X+6-O;6UA;F0M,3TB(#P\+T1U<&QE>"!F86QS92`O5'5M8FQE
M(&9A;'-E/CX@<V5T<&%G961E=FEC92`B"G!A9BUS970M9'5P;&5X+6-O;6UA
M;F0M,3TB(#P\+T1U<&QE>"!T<G5E("]4=6UB;&4@9F%L<V4^/B!S971P86=E
M9&5V:6-E("(*<&%F+7-E="UT=6UB;&4M8V]M;6%N9"TQ/2(@/#PO1'5P;&5X
M('1R=64@+U1U;6)L92!T<G5E/CX@<V5T<&%G961E=FEC92`B"@HC6TYO=&5=
M"B-;(%1H:7,@<')I;G1E<B!S=7!P;W)T<R!A;B!O<'1I;VYA;"!S=&%P;&5R
M(&%N9"!S=&%C:V5R(&9I;FES:&EN9R!U;FET"B-;(&-A<&%B;&4@;V8@;6%K
M:6YG(&UU;'1I<&QE(&]R:6=I;F%L(&1O8W5M96YT(&-O<&EE<R`H;6]P:65S
M*2X*(UL@5&\@96YA8FQE('1H92!O<'1I;VYA;"!S=&%P;&5R('-E=`HC6R`\
M='0^9FEN:7-H:6YG<RUS=7!P;W)T960](G-T87!L92!S=&%P;&4M=&]P+6QE
M9G0@<W1A<&QE+61U86PM;&5F="(\+W1T/@HC6R!O;B!T:&4@;&]G:6-A;"!A
M;F0@<&AY<VEC86P@<')I;G1E<G,L(&%N9`HC6R`\='0^9FEN:7-H:6YG<RUR
M96%D>3TB<W1A<&QE('-T87!L92UT;W`M;&5F="!S=&%P;&4M9'5A;"UL969T
M(CPO='0^"B-;(&]N('1H92!P:'ES:6-A;"!P<FEN=&5R(&]B:F5C="X@(`HC
M6T5N9$YO=&5="B-;3F]T95T*(UL@5&\@<VEN9VQE('-T87!L92!A(&1O8W5M
M96YT('-P96-I9GD@/'1T/F9I;FES:&EN9SUS=&%P;&4\+W1T/B!O<B`*(UL@
M/'1T/F9I;FES:&EN9RUS=&%P;&4M=&]P+6QE9G0\+W1T/B!W:71H('1H92!P
M<FEN="!R97%U97-T+B!&;W(*(UL@='=O('-T87!L97,@;VX@=&AE(&QO;F<M
M961G92!S:61E(&]F(&$@9&]C=6UE;G0@<W!E8VEF>0HC6R`\='0^9FEN:7-H
M:6YG/7-T87!L92UD=6%L+6QE9G0\+W1T/BX@4W1A<&QI;F<@<F5Q=6ER97,@
M"B-;(#QT=#YO=71P=70M8FEN/7-T86-K97(M,3PO='0^+"!S=&%C:V5R+3(L
M(&]R('-T86-K97(M,R!B92!S<&5C:69I960@=VET:`HC6R!T:&4@<')I;G0@
M<F5Q=65S="X*(UM%;F1.;W1E70HC6TYO=&5="B-;(%1O(&UA:V4@;75L=&EP
M;&4@<W1A<&QE9"!C;W!I97,@;V8@82!D;V-U;65N="!U<V4@=&AE(&-O<'DM
M8V]U;G0*(UL@871T<FEB=71E+"!N;W0@:F]B+6-O<&EE<RP@=VAE;B!S=6)M
M:71T:6YG(&$@<')I;G0@:F]B+B!4;R!D:7-A8FQE"B-;(&UU;'1I<&QE(&-O
M<'D@;6]D92!S970@/'1T/G!R:6YT97(M;75L=&EP;&4M8V]P>2UM;V1E/6YO
M/"]T=#XN"B-;16YD3F]T95T*"B,@<&%F+69I;FES:&EN9W,M<&]S<VEB;&4*
M,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C$Q-STB<W1A<&QE('-T87!L92UT
M;W`M;&5F="!S=&%P;&4M9'5A;"UL969T(@H*(R!P<FEN=&5R+6UU;'1I<&QE
M+6-O<'DM;6]D90HQ+C,N,3(N,BXQ,#$Q+C0N,RXS+C(N-3(]>65S"@HC('!A
M9BUD;V,M8V]P:65S+6-O;6UA;F0*,2XS+C$R+C(N,3`Q,2XT+C,N,RXR+C$R
M,"XQ,3TB(#P\+TYU;4-O<&EE<R`E9"`O0V]L;&%T92!T<G5E/CX@<V5T<&%G
M961E=FEC95Q<,#$R(@H*(R!P868M<W1A<&QE+71O<"UL969T+61O8RUC;VUM
M86YD"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XW,STB(#P\("]3=&%P;&4@
M,2`O4W1A<&QE1&5T86EL<R`\/"`O5'EP92`V("]3=&%P;&5-;V1E(#`@/CX@
M/CX@<V5T<&%G961E=FEC95Q<,#$R(@H*(R!P868M<W1A<&QE+6)O=&@M;&5F
M="UD;V,M8V]M;6%N9`HQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N-S<](B`\
M/"`O4W1A<&QE(#$@+U-T87!L941E=&%I;',@/#P@+U1Y<&4@-B`O4W1A<&QE
J36]D92`R(#X^(#X^('-E='!A9V5D979I8V5<7#`Q,B(*"B,@16YD+@H*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Xerox_DocuPrintN24_Level2PS.paf 31803 7
fi

exit 0
