#!/usr/bin/ksh
#
# Xerox DocuPrint N32
# Advanced Printing self-extracting installation script.
# Updated on 14-Dec-2000
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Xerox DocuPrint N32"
KIT_FILES="Xerox_DocuPrintN32_Level2PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-004" /usr/pd/share/cap/Xerox_DocuPrintN32_Level2PS.paf 09584 8)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Xerox_DocuPrintN32_Level2PS.paf
M(R!0<FEN=&5R($%T=')I8G5T92!&:6QE(&9O<B!897)O>"!$;V-U4')I;G0@
M3C(T+S,R+S0P('!R:6YT97(*(R!2978N(#$S+5-E<"TR,#`Q"B,*(R!#;W!Y
M<FEG:'0@,3DY."TR,#`Q($-O;7!A<2!#;VUP=71E<B!#;W)P;W)A=&EO;BX@
M($%L;"!2:6=H=',@4F5S97)V960N"B,*(R!0;W-T4V-R:7!T(&ES(&$@=')A
M9&5M87)K(&]F($%D;V)E(%-Y<W1E;7,@26YC;W)P;W)A=&5D+"!W:&EC:"`*
M(R!M87D@8F4@<F5G:7-T97)E9"!I;B!C97)T86EN(&IU<FES9&EC=&EO;G,N
M("`*"G!A9BUX+69I;&4M;F%M93U897)O>%]$;V-U4')I;G1.,S)?3&5V96PR
M4%,N<&%F"G!A9BUX+69I;&4M=F5R<VEO;CU!4%@M,2TP,#0*"G!R:6YT97(M
M;6]D96P](EAE<F]X($1O8W50<FEN="!.,S(B"G!R:6YT97(M=&-P:7`M<&]R
M="UN=6UB97(],C`P,`IM87AI;75M+7!R:6YT97(M<W!E960],S(*"F1O8W5M
M96YT+69O<FUA=',M<W5P<&]R=&5D/5!O<W138W)I<'0@<VEM<&QE+71E>'0*
M<&QE>&5S+7-U<'!O<G1E9#US:6UP;&5X"G-I9&5S+7-U<'!O<G1E9#TQ"FEN
M<'5T+71R87ES+7-U<'!O<G1E9#UT;W`@;6%I;B!S:61E(&UA;G5A;`IO=71P
M=70M8FEN<RUS=7!P;W)T960]=&]P('-I9&4@9F%C92UU<`H*9&]C=6UE;G0M
M9F]R;6%T<RUR96%D>3U0;W-T4V-R:7!T('-I;7!L92UT97AT"FYA=&EV92UD
M;V-U;65N="UF;W)M871S+7)E861Y/5!O<W138W)I<'0*<VED97,M<F5A9'D]
M,0II;G!U="UT<F%Y<RUR96%D>3UT;W`@;6%I;B!S:61E(&UA;G5A;`IO=71P
M=70M8FEN<RUR96%D>3UT;W`@<VED92!F86-E+75P"@HC('!R:79A=&4@<W5P
M97)V:7-O<B!A='1R:6)U=&5S"@IP868M:7,M<&IL/71R=64*<&%F+6YA=&EV
M92UD;V-U;65N="UF;W)M870M,3U0;W-T4V-R:7!T"G!A9BUD969A=6QT+61O
M8W5M96YT+69O<FUA=#U0;W-T4V-R:7!T"G!A9BUJ;V(M<V5P87)A=&]R+69O
M<FUA=#U0;W-T4V-R:7!T"G!A9BUS=&%R="UP9&PM,2UC;VUM86YD/2)<7#`Q
M,B4A7%PP,3(B"@HC(&-O;FYE8W1I;VXM<F5L871E9"!A='1R:6)U=&5S"@IP
M868M8V]N;F5C=&EO;BUL979E;"US97)I86P],PIP868M8V]N;F5C=&EO;BUL
M979E;"UP87)A;&QE;#TR"G!A9BUC;VYN96-T:6]N+6QE=F5L+6EP+7-O8VME
M=#TS"@HC($UE9&EA('-E;&5C=&EO;@H@"B,@4&%F($%T=')I8G5T92`@("`@
M("`@($])1"!.=6UB97(@("`@("`@("`@("`@("`@("`@($%L:6%S($YA;64H
M<RD@"B,@+2TM+2TM+2TM+2TM+2TM+2TM+2`@("TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T@(%]?7U]?7U]?7U]?7U\*(R!P868M,2UM961I82UC;VUM
M86YD("`@,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+CDU("`@3&5T=&5R+"!!
M"B,@<&%F+3(M;65D:6$M8V]M;6%N9"`@(#$N,BXX-#`N,3$S-34P+C$N,RXR
M+C$R,"XY-R`@($QE9&=E<BP@0@HC('!A9BTS+6UE9&EA+6-O;6UA;F0@("`Q
M+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N.3D@("!!,PHC('!A9BTT+6UE9&EA
M+6-O;6UA;F0@("`Q+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N,3`Q("!!-`H*
M,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+CDU/2(@/#P@+U!A9V53:7IE(%LV
M,3(@-SDR72`@+TEM86=I;F="0F]X(&YU;&P@/CX@<V5T<&%G961E=FEC92`B
M"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XY-STB(#P\("]086=E4VEZ92!;
M-SDR(#$R,C1=("]);6%G:6YG0D)O>"!N=6QL(#X^('-E='!A9V5D979I8V4@
M(@HQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N.3D](B`\/"`O4&%G95-I>F4@
M6S@T,B`Q,3DQ72`O26UA9VEN9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E
M("(*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C$P,3TB(#P\("]086=E4VEZ
M92!;-3DU(#@T,ET@+TEM86=I;F="0F]X(&YU;&P@/CX@<V5T<&%G961E=FEC
M92`B"@HC('!A9BUM961I82UA;&EA<V5S"C$N,BXX-#`N,3$S-34P+C$N,RXR
M+C$R,"XW.3TB;&5T=&5R.C$@83HQ(&QE9&=E<CHR(&(Z,B!A,SHS(&$T.C0B
M"@HC($EN<'5T('1R87D@<V5L96-T:6]N(&-O;6UA;F1S"B,*(R!$979I8V4@
M=')A>2!N86UE("!-961I85!O<VET:6]N("`@1%!!($UA<'!E9"!N86UE("!3
M=&0O3W!T:6]N"B,@+2TM+2TM+2TM+2TM+2TM+2`@+2TM+2TM+2TM+2TM+2`@
M("TM+2TM+2TM+2TM+2TM+2`@+2TM+2TM+2TM+0HC(%1R87D@,2`@("`@("`@
M("`@("`@("`@*#`I("`@("`@("!T;W`@("`@("`@("`@("`@('-T86YD87)D
M"B,@5')A>2`R("`@("`@("`@("`@("`@("`H,2D@("`@("`@(&UA:6X@("`@
M("`@("`@("`@<W1A;F1A<F0*(R!4<F%Y(#,@("`@("`@("`@("`@("`@("@R
M*2`@("`@("`@;6ED9&QE("`@("`@("`@("!O<'1I;VX*(R!4<F%Y(#0@("`@
M("`@("`@("`@("`@("@S*2`@("`@("`@;&%R9V4M8V%P86-I='D@("!O<'1I
M;VX*(R!4<F%Y(#4@("`@("`@("`@("`@("`@("@T*2`@("`@("`@8F]T=&]M
M("`@("`@("`@("!O<'1I;VX*(R!-0D8@("`@("`@("`@("`@("`@("`@("@U
M*2`@("`@("`@<VED92`@("`@("`@("`@("!S=&%N9&%R9`HC($5N=F5L;W!E
M("`@("`@("`@("`@("`@*#8I("`@("`@("!E;G9E;&]P92`@("`@("`@(&]P
M=&EO;@HC($UA;G5A;"!&965D("`@("`@("`@("`@("T@("`@("`@("!M86YU
M86P@("`@("`@("`@('-T86YD87)D"@IP868M=&]P+6EN<'5T+6-O;6UA;F0M
M,3TB(#`@<W1A='5S9&EC="`O<V5T<&%P97)T<F%Y(&=E="!E>&5C("(*<&%F
M+6UA:6XM:6YP=70M8V]M;6%N9"TQ/2(@,2!S=&%T=7-D:6-T("]S971P87!E
M<G1R87D@9V5T(&5X96,@(@IP868M;6ED9&QE+6EN<'5T+6-O;6UA;F0M,3TB
M(#(@<W1A='5S9&EC="`O<V5T<&%P97)T<F%Y(&=E="!E>&5C("(*<&%F+6QA
M<F=E+6-A<&%C:71Y+6EN<'5T+6-O;6UA;F0M,3TB(#,@<W1A='5S9&EC="`O
M<V5T<&%P97)T<F%Y(&=E="!E>&5C("(*<&%F+6)O='1O;2UI;G!U="UC;VUM
M86YD+3$](B`T('-T871U<V1I8W0@+W-E='!A<&5R=')A>2!G970@97AE8R`B
M"G!A9BUS:61E+6EN<'5T+6-O;6UA;F0M,3TB(#4@<W1A='5S9&EC="`O<V5T
M<&%P97)T<F%Y(&=E="!E>&5C("(*<&%F+65N=F5L;W!E+6EN<'5T+6-O;6UA
M;F0M,3TB(#8@<W1A='5S9&EC="`O<V5T<&%P97)T<F%Y(&=E="!E>&5C("(*
M<&%F+6UA;G5A;"UI;G!U="UC;VUM86YD+3$](B!S=&%T=7-D:6-T("]M86YU
M86QF965D('1R=64@<'5T("(*"B,@3G5M8F5R960@=')A>7,@87)E('-U<'!O
M<G1E9"!B>2!T:&4@5C$N,2!S=7!E<G9I<V]R"@IP868M,2UI;G!U="UC;VUM
M86YD+3$](B`P('-T871U<V1I8W0@+W-E='!A<&5R=')A>2!G970@97AE8R`B
M"G!A9BTR+6EN<'5T+6-O;6UA;F0M,3TB(#$@<W1A='5S9&EC="`O<V5T<&%P
M97)T<F%Y(&=E="!E>&5C("(*<&%F+3,M:6YP=70M8V]M;6%N9"TQ/2(@,B!S
M=&%T=7-D:6-T("]S971P87!E<G1R87D@9V5T(&5X96,@(@IP868M-"UI;G!U
M="UC;VUM86YD+3$](B`S('-T871U<V1I8W0@+W-E='!A<&5R=')A>2!G970@
M97AE8R`B"G!A9BTU+6EN<'5T+6-O;6UA;F0M,3TB(#0@<W1A='5S9&EC="`O
M<V5T<&%P97)T<F%Y(&=E="!E>&5C("(*"B,@3W5T<'5T(&)I;B!S96QE8W1I
M;VX@8V]M;6%N9',*(`IP868M=&]P+6]U='!U="UC;VUM86YD+3$](B`\/"]/
M=71P=714>7!E("A&04-%($1/5TX@5%)!62D^/B!S971P86=E9&5V:6-E("(*
M<&%F+7-I9&4M;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$9!
M0T4@55`@5%)!62D^/B!S971P86=E9&5V:6-E("(*<&%F+69A8V4M=7`M;W5T
M<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$9!0T4@55`@5%)!62D^
M/B!S971P86=E9&5V:6-E("(*<&%F+6QA<F=E+6]U='!U="UC;VUM86YD+3$]
M(B`\/"]/=71P=714>7!E("A&24Y)4TA%4B!"24X@,2D^/B!S971P86=E9&5V
M:6-E("(*"B,@36%I;&)O>&5S(&%N9"!S=&%C:V5R<R!A<F4@<W5P<&]R=&5D
M(&)Y('1H92!6,2XQ('-U<&5R=FES;W(*"G!A9BUM86EL8F]X+3$M;W5T<'5T
M+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$U!24Q"3U@@0DE.(#$I/CX@
M<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+3(M;W5T<'5T+6-O;6UA;F0M
M,3TB(#P\+T]U='!U=%1Y<&4@*$U!24Q"3U@@0DE.(#(I/CX@<V5T<&%G961E
M=FEC92`B"G!A9BUM86EL8F]X+3,M;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U
M='!U=%1Y<&4@*$U!24Q"3U@@0DE.(#,I/CX@<V5T<&%G961E=FEC92`B"G!A
M9BUM86EL8F]X+30M;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@
M*$U!24Q"3U@@0DE.(#0I/CX@<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X
M+34M;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$U!24Q"3U@@
M0DE.(#4I/CX@<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+38M;W5T<'5T
M+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$U!24Q"3U@@0DE.(#8I/CX@
M<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+3<M;W5T<'5T+6-O;6UA;F0M
M,3TB(#P\+T]U='!U=%1Y<&4@*$U!24Q"3U@@0DE.(#<I/CX@<V5T<&%G961E
M=FEC92`B"G!A9BUM86EL8F]X+3@M;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U
M='!U=%1Y<&4@*$U!24Q"3U@@0DE.(#@I/CX@<V5T<&%G961E=FEC92`B"G!A
M9BUM86EL8F]X+3DM;W5T<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@
M*$U!24Q"3U@@0DE.(#DI/CX@<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X
M+3$P+6]U='!U="UC;VUM86YD+3$](B`\/"]/=71P=714>7!E("A-04E,0D]8
M($))3B`Q,"D^/B!S971P86=E9&5V:6-E("(*"G!A9BUS=&%C:V5R+3$M;W5T
M<'5T+6-O;6UA;F0M,3TB(#P\+T]U='!U=%1Y<&4@*$9)3DE32$52($))3B`Q
M*3X^('-E='!A9V5D979I8V4@(@IP868M<W1A8VME<BTR+6]U='!U="UC;VUM
M86YD+3$](B`\/"]/=71P=714>7!E("A&24Y)4TA%4B!"24X@,BD^/B!S971P
M86=E9&5V:6-E("(*<&%F+7-T86-K97(M,RUO=71P=70M8V]M;6%N9"TQ/2(@
M/#PO3W5T<'5T5'EP92`H1DE.25-(15(@0DE.(#,I/CX@<V5T<&%G961E=FEC
M92`B"@HC('!A9BUI;G!U="UT<F%Y<RUP;W-S:6)L90HQ+C(N.#0P+C$Q,S4U
M,"XQ+C,N,BXQ,C`N.#,](G1O<"!M86EN(&UI9&1L92!M86YU86P@;&%R9V4M
M8V%P86-I='D@8F]T=&]M('-I9&4@96YV96QO<&4@,2`R(#,@-"`U(@H*(R!P
M868M;W5T<'5T+6)I;G,M<&]S<VEB;&4*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N
M,3(P+C@T/2)T;W`@<VED92!F86-E+75P(&QA<F=E('-T86-K97(M,2!S=&%C
M:V5R+3(@<W1A8VME<BTS(#$@,B`S(#0@-2`V(#<@."`Y(#$P(&UA:6QB;W@M
M,2!M86EL8F]X+3(@;6%I;&)O>"TS(&UA:6QB;W@M-"!M86EL8F]X+34@;6%I
M;&)O>"TV(&UA:6QB;W@M-R!M86EL8F]X+3@@;6%I;&)O>"TY(&UA:6QB;W@M
M,3`B"@HC('!A9BUI;G!U="UT<F%Y+6%L:6%S97,*,2XR+C@T,"XQ,3,U-3`N
M,2XS+C(N,3(P+C0R/2(Q.G1O<"`R.FUA:6X@,SIM:61D;&4@-#IL87)G92UC
M87!A8VET>2`U.F)O='1O;2(*"B,@<&%F+6]U='!U="UB:6XM86QI87-E<PHQ
M+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N-#,](C$Z;6%I;&)O>"TQ(#(Z;6%I
M;&)O>"TR(#,Z;6%I;&)O>"TS(#0Z;6%I;&)O>"TT(#4Z;6%I;&)O>"TU(#8Z
M;6%I;&)O>"TV(#<Z;6%I;&)O>"TW(#@Z;6%I;&)O>"TX(#DZ;6%I;&)O>"TY
M(#$P.FUA:6QB;W@M,3`B"@HC(%-I9&5S('-E;&5C=&EO;B!C;VUM86YD<PH@
M"G!A9BUS970M<VEM<&QE>"UC;VUM86YD+3$](B`\/"]$=7!L97@@9F%L<V4@
M+U1U;6)L92!F86QS93X^('-E='!A9V5D979I8V4@(@IP868M<V5T+61U<&QE
M>"UC;VUM86YD+3$](B`\/"]$=7!L97@@=')U92`O5'5M8FQE(&9A;'-E/CX@
M<V5T<&%G961E=FEC92`B"G!A9BUS970M='5M8FQE+6-O;6UA;F0M,3TB(#P\
M+T1U<&QE>"!T<G5E("]4=6UB;&4@=')U93X^('-E='!A9V5D979I8V4@(@H*
M(R!P868M9FEN:7-H:6YG<RUP;W-S:6)L90HQ+C(N.#0P+C$Q,S4U,"XQ+C,N
M,BXQ,C`N,3$W/2)S=&%P;&4@<W1A<&QE+71O<"UL969T('-T87!L92UD=6%L
M+6QE9G0B"@HC('!R:6YT97(M;75L=&EP;&4M8V]P>2UM;V1E"C$N,RXQ,BXR
M+C$P,3$N-"XS+C,N,BXU,CUY97,*"B,@<&%F+61O8RUC;W!I97,M8V]M;6%N
M9`HQ+C,N,3(N,BXQ,#$Q+C0N,RXS+C(N,3(P+C$Q/2(@/#PO3G5M0V]P:65S
M("5D("]#;VQL871E('1R=64^/B!S971P86=E9&5V:6-E7%PP,3(B"@HC('!A
M9BUS=&%P;&4M=&]P+6QE9G0M9&]C+6-O;6UA;F0*,2XR+C@T,"XQ,3,U-3`N
M,2XS+C(N,3(P+C<S/2(@/#P@+U-T87!L92`Q("]3=&%P;&5$971A:6QS(#P\
M("]4>7!E(#8@+U-T87!L94UO9&4@,"`^/B`^/B!S971P86=E9&5V:6-E7%PP
M,3(B"@HC('!A9BUS=&%P;&4M8F]T:"UL969T+61O8RUC;VUM86YD"C$N,BXX
M-#`N,3$S-34P+C$N,RXR+C$R,"XW-STB(#P\("]3=&%P;&4@,2`O4W1A<&QE
M1&5T86EL<R`\/"`O5'EP92`V("]3=&%P;&5-;V1E(#(@/CX@/CX@<V5T<&%G
M961E=FEC95Q<,#$R(@H*(UM.;W1E70HC6R!4:&ES('!R:6YT97(@<W5P<&]R
M=',@86X@;W!T:6]N86P@<W1A<&QE<B!A;F0@<W1A8VME<B!F:6YI<VAI;F<@
M=6YI=`HC6R!C87!A8FQE(&]F(&UA:VEN9R!M=6QT:7!L92!O<FEG:6YA;"!D
M;V-U;65N="!C;W!I97,@*&UO<&EE<RDN"B-;(%1O(&5N86)L92!T:&4@;W!T
M:6]N86P@<W1A<&QE<B!S970*(UL@/'1T/F9I;FES:&EN9W,M<W5P<&]R=&5D
M/2)S=&%P;&4@<W1A<&QE+71O<"UL969T('-T87!L92UD=6%L+6QE9G0B/"]T
M=#X*(UL@;VX@=&AE(&QO9VEC86P@86YD('!H>7-I8V%L('!R:6YT97)S+"!A
M;F0*(UL@/'1T/F9I;FES:&EN9W,M<F5A9'D](G-T87!L92!S=&%P;&4M=&]P
M+6QE9G0@<W1A<&QE+61U86PM;&5F="(\+W1T/@HC6R!O;B!T:&4@<&AY<VEC
M86P@<')I;G1E<B!O8FIE8W0N("`*(UM%;F1.;W1E70HC6TYO=&5="B-;(%1O
M('-I;F=L92!S=&%P;&4@82!D;V-U;65N="!S<&5C:69Y(#QT=#YF:6YI<VAI
M;F<]<W1A<&QE/"]T=#X@;W(@"B-;(#QT=#YF:6YI<VAI;F<M<W1A<&QE+71O
M<"UL969T/"]T=#X@=VET:"!T:&4@<')I;G0@<F5Q=65S="X@1F]R"B-;('1W
M;R!S=&%P;&5S(&]N('1H92!L;VYG+65D9V4@<VED92!O9B!A(&1O8W5M96YT
M('-P96-I9GD*(UL@/'1T/F9I;FES:&EN9SUS=&%P;&4M9'5A;"UL969T/"]T
M=#XN(%-T87!L:6YG(')E<75I<F5S(`HC6R`\='0^;W5T<'5T+6)I;CUS=&%C
M:V5R+3$\+W1T/BP@<W1A8VME<BTR+"!O<B!S=&%C:V5R+3,@8F4@<W!E8VEF
M:65D('=I=&@*(UL@=&AE('!R:6YT(')E<75E<W0N"B-;16YD3F]T95T*(UM.
M;W1E70HC6R!4;R!M86ME(&UU;'1I<&QE('-T87!L960@8V]P:65S(&]F(&$@
M9&]C=6UE;G0@=7-E('1H92!C;W!Y+6-O=6YT(`HC6R!A='1R:6)U=&4L(&YO
M="!J;V(M8V]P:65S+"!W:&5N('-U8FUI='1I;F<@82!P<FEN="!J;V(N(%1O
M(&1I<V%B;&4*(UL@;75L=&EP;&4@8V]P>2!M;V1E('-E="`\='0^<')I;G1E
M<BUM=6QT:7!L92UC;W!Y+6UO9&4];F\\+W1T/BX*(UM%;F1.;W1E70H*(R!%
$;F0N"FQT
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Xerox_DocuPrintN32_Level2PS.paf 09584 8
fi

exit 0
