#!/usr/bin/ksh
#
# Xerox DocuPrint N32
# LPD self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V5.1"
KIT_TYPE=$KIT_LPD
KIT_PRINTER="Xerox DocuPrint N32"
KIT_FILES="xeroxN32.rpd Xerox_DocuPrint_N32.lpd"

function setupInstructions {
    mimimumVersionTest V5.1B
    if [[ $? != 0 ]]
    then
	print "Use lprsetup(8) to create an /etc/printcap file entry, specifying" >&2
	print "the printer type "ln17". This creates the entry for your new printer." >&2
	print "Then edit the printcap entry and apply the following changes:" >&2
	print "" >&2
	print "	:if=/usr/lbin/ppdof +OPageSize=Letter +CxeroxN32.rpd:\\" >&2
	print "	:of=/usr/lbin/ppdof +OPageSize=Letter +CxeroxN32.rpd:\\" >&2
	print "	:pw#0:\\" >&2
    else
	print "Use lprsetup(8) to create a new /etc/printcap file entry. Driver" >&2
	print "updates will not impact the current /etc/printcap entries." >&2
    fi
    print "" >&2
    print "For additional information refer to printcap(4) \c" >&2
    if [[ ! -z `find /usr/man/man8/ -name ppdof\*` ]]
    then
	print "and ppdof(8) man pages." >&2
    else
	print "man page." >&2
    fi
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "1.0" /usr/lbin/ppd/xeroxN32.rpd 27556 4)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/ppd/xeroxN32.rpd
M*D9I;&5697)S:6]N.B`B,2XP(@HJ4')O9'5C=#H@(BA897)O>"!$;V-U4')I
M;G0@3C,R*2(**DUO9&5L3F%M93H@(EAE<F]X($1O8W50<FEN="!.,S(B"BI0
M4U9E<G-I;VXZ("(H,S`Q,"XQ,#8I(#$B"BI,86YG=6%G94QE=F5L.B`B,R(*
M*E!#1FEL94YA;64Z(")X97)O>$XS,BYR<&0B"BI/<F1E<D1E<&5N9&5N8WDZ
M(#,P($%N>5-E='5P("I$=7!L97@**D1U<&QE>"!$=7!L97A.;U1U;6)L92]$
M=7!L97@Z("(\/"]$=7!L97@@=')U92`O5'5M8FQE(&9A;'-E/CX@<V5T<&%G
M961E=FEC92(**D1U<&QE>"!$=7!L97A4=6UB;&4O1'5P;&5X(%1U;6)L93H@
M(CP\+T1U<&QE>"!T<G5E("]4=6UB;&4@=')U93X^('-E='!A9V5D979I8V4B
M"BI$=7!L97@@3F]N92]3:6UP;&5X.B`B/#PO1'5P;&5X(&9A;'-E("]4=6UB
M;&4@9F%L<V4^/B!S971P86=E9&5V:6-E(@HJ3W)D97)$97!E;F1E;F-Y.B`R
M,"!!;GE3971U<"`J4&%G95-I>F4**E!A9V53:7IE($$T+T$T(#(Q,"!X(#(Y
M-R!M;3H@(CP\("]086=E4VEZ92!;-3DU(#@T,ET@+TEM86=I;F="0F]X(&YU
M;&P@/CX@<V5T<&%G961E=FEC92(**E!A9V53:7IE($QE9V%L+TQE9V%L(#@@
M,2\R('@@,30@:6XZ("(\/"`O4&%G95-I>F4@6S8Q,B`Q,#`X72`O26UA9VEN
M9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E(@HJ4&%G95-I>F4@3&5T=&5R
M+TQE='1E<B`X(#$O,B!X(#$Q(&EN.B`B/#P@+U!A9V53:7IE(%LV,3(@-SDR
M72`O26UA9VEN9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E(@HJ4&%G95-I
M>F4@5&%B;&]I9"]486)L;VED(#$Q('@@,3<@:6XZ("(\/"`O4&%G95-I>F4@
M6S<Y,B`Q,C(T72`O26UA9VEN9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E
M(@HJ4&%P97)$:6UE;G-I;VX@030Z("(U.34@.#0R(@HJ4&%P97)$:6UE;G-I
M;VX@3&5G86PZ("(V,3(@,3`P."(**E!A<&5R1&EM96YS:6]N($QE='1E<CH@
M(C8Q,B`W.3(B"BI087!E<D1I;65N<VEO;B!486)L;VED.B`B-SDR(#$R,C0B
M"BI);6%G96%B;&5!<F5A($$T.B`B,3`N,"`Q,"XP(#4Y,"XP(#@S-RXP(@HJ
M26UA9V5A8FQE07)E82!,96=A;#H@(C4N,"`U+C`@-C`W+C`@.3DX+C`B"BI)
M;6%G96%B;&5!<F5A($QE='1E<CH@(C$P+C`@,3`N,"`V,#<N,"`W.#<N,"(*
M*DEM86=E86)L94%R96$@5&%B;&]I9#H@(C$P+C`@-2XP(#<X-RXP(#$R,30N
M,"(**D]R9&5R1&5P96YD96YC>3H@,34@06YY4V5T=7`@*DEN<'5T4VQO=`HJ
M26YP=713;&]T(&UA;G5A;"]-0D8Z("(\/"`O365D:6%0;W-I=&EO;B`U(#X^
M('-E='!A9V5D979I8V4B"BI);G!U=%-L;W0@=')A>3$O5')A>2`Q.B`B/#P@
M+TUE9&EA4&]S:71I;VX@,"`^/B!S971P86=E9&5V:6-E(@HJ26YP=713;&]T
M('1R87DR+U1R87D@,CH@(CP\("]-961I85!O<VET:6]N(#$@/CX@<V5T<&%G
M961E=FEC92(**DEN<'5T4VQO="!T<F%Y,R]4<F%Y(#,Z("(\/"`O365D:6%0
M;W-I=&EO;B`R(#X^('-E='!A9V5D979I8V4B"BI);G!U=%-L;W0@=')A>30O
M5')A>2`T.B`B/#P@+TUE9&EA4&]S:71I;VX@,R`^/B!S971P86=E9&5V:6-E
M(@HJ26YP=713;&]T('1R87DU+U1R87D@-3H@(CP\("]-961I85!O<VET:6]N
M(#0@/CX@<V5T<&%G961E=FEC92(**D]R9&5R1&5P96YD96YC>3H@,S`@06YY
M4V5T=7`@*D]U='!U=$)I;@HJ3W5T<'5T0FEN(&9A8V5D;W=N+T9A8V4@1&]W
M;B!":6XZ("(\/"]/=71P=714>7!E("A&04-%($1/5TX@5%)!62D^/B!S971P
M86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&9A8V5U<"]&86-E(%5P($)I;CH@(CP\
M+T]U='!U=%1Y<&4@*$9!0T4@55`@5%)!62D^/B!S971P86=E9&5V:6-E(@HJ
M3W5T<'5T0FEN(&)I;C$O1FEN:7-H97(@0FEN(#$Z("(\/"]/=71P=714>7!E
M("A&24Y)4TA%4B!"24X@,2D^/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN
M(&)I;C(O1FEN:7-H97(@0FEN(#(Z("(\/"]/=71P=714>7!E("A&24Y)4TA%
M4B!"24X@,BD^/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&)I;C,O1FEN
M:7-H97(@0FEN(#,Z("(\/"]/=71P=714>7!E("A&24Y)4TA%4B!"24X@,RD^
M/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&UB,2]-86EL8F]X($)I;B`Q
M.B`B/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@,2D^/B!S971P86=E9&5V
M:6-E(@HJ3W5T<'5T0FEN(&UB,B]-86EL8F]X($)I;B`R.B`B/#PO3W5T<'5T
M5'EP92`H34%)3$)/6"!"24X@,BD^/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T
M0FEN(&UB,R]-86EL8F]X($)I;B`S.B`B/#PO3W5T<'5T5'EP92`H34%)3$)/
M6"!"24X@,RD^/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&UB-"]-86EL
M8F]X($)I;B`T.B`B/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@-"D^/B!S
M971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&UB-2]-86EL8F]X($)I;B`U.B`B
M/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@-2D^/B!S971P86=E9&5V:6-E
M(@HJ3W5T<'5T0FEN(&UB-B]-86EL8F]X($)I;B`V.B`B/#PO3W5T<'5T5'EP
M92`H34%)3$)/6"!"24X@-BD^/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN
M(&UB-R]-86EL8F]X($)I;B`W.B`B/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"
M24X@-RD^/B!S971P86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&UB."]-86EL8F]X
M($)I;B`X.B`B/#PO3W5T<'5T5'EP92`H34%)3$)/6"!"24X@."D^/B!S971P
M86=E9&5V:6-E(@HJ3W5T<'5T0FEN(&UB.2]-86EL8F]X($)I;B`Y.B`B/#PO
M3W5T<'5T5'EP92`H34%)3$)/6"!"24X@.2D^/B!S971P86=E9&5V:6-E(@HJ
M3W5T<'5T0FEN(&UB,3`O36%I;&)O>"!":6X@,3`Z("(\/"]/=71P=714>7!E
M("A-04E,0D]8($))3B`Q,"D^/B!S971P86=E9&5V:6-E(@HJ1F]N="!!=F%N
M=$=A<F1E+4)O;VLZ("(B"BI&;VYT($%V86YT1V%R9&4M0F]O:T]B;&EQ=64Z
M("(B"BI&;VYT($%V86YT1V%R9&4M1&5M:3H@(B(**D9O;G0@079A;G1'87)D
M92U$96UI3V)L:7%U93H@(B(**D9O;G0@0V]U<FEE<CH@(B(**D9O;G0@0V]U
M<FEE<BU";VQD.B`B(@HJ1F]N="!#;W5R:65R+4)O;&1/8FQI<75E.B`B(@HJ
M1F]N="!#;W5R:65R+4]B;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC83H@(B(*
M*D9O;G0@2&5L=F5T:6-A+4)O;&0Z("(B"BI&;VYT($AE;'9E=&EC82U";VQD
M3V)L:7%U93H@(B(**D9O;G0@2&5L=F5T:6-A+4YA<G)O=SH@(B(**D9O;G0@
M2&5L=F5T:6-A+4YA<G)O=RU";VQD.B`B(@HJ1F]N="!(96QV971I8V$M3F%R
M<F]W+4)O;&1/8FQI<75E.B`B(@HJ1F]N="!(96QV971I8V$M3F%R<F]W+4]B
M;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC82U/8FQI<75E.B`B(@HJ1F]N="!.
M97=#96YT=7)Y4V-H;&)K+4)O;&0Z("(B"BI&;VYT($YE=T-E;G1U<GE38VAL
M8FLM0F]L9$ET86QI8SH@(B(**D9O;G0@3F5W0V5N='5R>5-C:&QB:RU)=&%L
M:6,Z("(B"BI&;VYT($YE=T-E;G1U<GE38VAL8FLM4F]M86XZ("(B"BI&;VYT
M(%1I;65S+4)O;&0Z("(B"BI&;VYT(%1I;65S+4)O;&1)=&%L:6,Z("(B"BI&
K;VYT(%1I;65S+4ET86QI8SH@(B(**D9O;G0@5&EM97,M4F]M86XZ("(B"BI&
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/ppd/xeroxN32.rpd 27556 4
fi

backup_file=$(preInstall "1.1.4.1" /usr/lbin/lprsetup/Xerox_DocuPrint_N32.lpd 00758 1)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/lprsetup/Xerox_DocuPrint_N32.lpd
M(R!`*",I)%)#4V9I;&4Z(%AE<F]X7T1O8W50<FEN=%].,S(N;'!D+'8@)"`D
M4F5V:7-I;VXZ(#$N,2XT+C$@)"`D1&%T93H@,C`P,2\P.2\Q-R`Q-#HP-CHQ
M.2`D"G!R:6YT97(Z7`H@("`@.E!./5AE<F]X($1O8W50<FEN="!.,S(Z7`H@
M("`@.F)R/3DV,#`Z7`H@("`@.F9C/3`Q-S<W-S<Z7`H@("`@.F9S/3`S.EP*
M("`@(#II9CTO=7-R+VQB:6XO<'!D;V8@*T]086=E4VEZ93U,971T97(@*T-X
M97)O>$XS,BYR<&0Z7`H@("`@.F]F/2]U<W(O;&)I;B]P<&1O9B`K3U!A9V53
M:7IE/4QE='1E<B`K0WAE<F]X3C,R+G)P9#I<"B`@("`Z>&8]+W5S<B]L8FEN
M+WAF.EP*("`@(#IM>#TP.EP*("`@(#IP;#TV-CI<"B`@("`Z<'<],#I<"B`@
M("`Z<G<];VXZ7`H@("`@.GAC/3`Q-S<W-S<Z7`H@("`@.GAS/3`T-#`P,#I<
M"B`@("`Z4$0]7&Y<"E1H92!897)O>"!$;V-U4')I;G0@3C,R(&ES(&$@,S(@
M<'!M(%!#3"!A;F0@4&]S=%-C<FEP="!L87-E<B!P<FEN=&5R+EP*7&Y<;CH*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/lprsetup/Xerox_DocuPrint_N32.lpd 00758 1
fi

mimimumVersionTest V5.1B
if [[ $? = 0 ]] && [[ $FileInstalled > 0 ]]
then
    if [[ -z $(/usr/sbin/lprsetup -c update) ]]
    then
        print "File /etc/lprsetup.dat was backed up then updated."
    fi
fi
exit 0
