#!/usr/bin/ksh
#
# Xerox Document Centre 432 ST
# LPD self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V5.1"
KIT_TYPE=$KIT_LPD
KIT_PRINTER="Xerox Document Centre 432 ST"
KIT_FILES="xeroxDC432.rpd Xerox_Document_Centre_432ST.lpd"

function setupInstructions {
    mimimumVersionTest V5.1B
    if [[ $? != 0 ]]
    then
	print "Use lprsetup(8) to create an /etc/printcap file entry, specifying" >&2
	print "the printer type "ln17". This creates the entry for your new printer." >&2
	print "Then edit the printcap entry and apply the following changes:" >&2
	print "" >&2
	print "	:if=/usr/lbin/ppdof +OPageSize=Letter +IFsetup +CxeroxDC432.rpd:\\" >&2
	print "	:of=/usr/lbin/ppdof +OPageSize=Letter +OFsetup +CxeroxDC432.rpd:\\" >&2
	print "	:pw#0:\\" >&2
    else
	print "Use lprsetup(8) to create a new /etc/printcap file entry. Driver" >&2
	print "updates will not impact the current /etc/printcap entries." >&2
    fi
    print "" >&2
    print "For additional information refer to printcap(4) \c" >&2
    if [[ ! -z `find /usr/man/man8/ -name ppdof\*` ]]
    then
	print "and ppdof(8) man pages." >&2
    else
	print "man page." >&2
    fi
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "1.0" /usr/lbin/ppd/xeroxDC432.rpd 14082 7)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/ppd/xeroxDC432.rpd
M*D9I;&5697)S:6]N.B`B,2XP(@HJ4')O9'5C=#H@(BA897)O>"!$;V-U;65N
M="!#96YT<F4@-#,R+S0T,%-4*2(**DUO9&5L3F%M93H@(EAE<F]X($1O8W5M
M96YT($-E;G1R92`T,S(@4U0B"BI04U9E<G-I;VXZ("(H,S`Q,"XQ,#8I(#(R
M,#`B"BI,86YG=6%G94QE=F5L.B`B,R(**E!#1FEL94YA;64Z(")X97)O>$1#
M-#,R+G)P9"(*"BI/<F1E<D1E<&5N9&5N8WDZ(#4X($%N>5-E='5P("I$=7!L
M97@**D1U<&QE>"!$=7!L97A.;U1U;6)L92]$=7!L97@Z("(\/"`O1'5P;&5X
M('1R=64@+U1U;6)L92!F86QS92`^/B!S971P86=E9&5V:6-E(@HJ1'5P;&5X
M($1U<&QE>%1U;6)L92]$=7!L97@@='5M8FQE.B`B/#P@+T1U<&QE>"!T<G5E
M("]4=6UB;&4@=')U92`^/B!S971P86=E9&5V:6-E(@HJ1'5P;&5X($YO;F4O
M4VEM<&QE>#H@(CP\("]$=7!L97@@9F%L<V4@+U1U;6)L92!F86QS92`^/B!S
M971P86=E9&5V:6-E(@H**D]R9&5R1&5P96YD96YC>3H@-#8@06YY4V5T=7`@
M*DUE9&EA5'EP90HJ365D:6%4>7!E(%!A<&5R+U!L86EN('!A<&5R.B`B/#P@
M+TUE9&EA5'EP92`H4W1A;F1A<F0I(#X^('-E='!A9V5D979I8V4B"BI-961I
M851Y<&4@5')A;G-P87)E;F-Y+U1R86YS<&%R96YC>3H@(CP\("]$=7!L97@@
M9F%L<V4@+TUE9&EA5'EP92`H=')A;G-P87)E;F-Y*2`^/B!S971P86=E9&5V
M:6-E(@H**D]R9&5R1&5P96YD96YC>3H@-#(@06YY4V5T=7`@*E!A9V53:7IE
M"BI086=E4VEZ92!!-"]!-"`R,3`@>"`R.3<@;6TZ("(\/"`O4&%G95-I>F4@
M6S4Y-2`X-#)=("]);6%G:6YG0D)O>"!N=6QL(#X^('-E='!A9V5D979I8V4B
M"BI086=E4VEZ92!,96=A;"],96=A;"`X(#$O,B!X(#$T(&EN.B`B/#P@+U!A
M9V53:7IE(%LV,3(@,3`P.%T@+TEM86=I;F="0F]X(&YU;&P@/CX@<V5T<&%G
M961E=FEC92(**E!A9V53:7IE($QE='1E<B],971T97(@."`Q+S(@>"`Q,2!I
M;CH@(CP\("]086=E4VEZ92!;-C$R(#<Y,ET@+TEM86=I;F="0F]X(&YU;&P@
M/CX@<V5T<&%G961E=FEC92(**E!A9V53:7IE(%1A8FQO:60O5&%B;&]I9"`Q
M,2!X(#$W(&EN.B`B/#P@+U!A9V53:7IE(%LW.3(@,3(R-%T@+TEM86=I;F="
M0F]X(&YU;&P@/CX@<V5T<&%G961E=FEC92(**E!A<&5R1&EM96YS:6]N($$T
M.B`B-3DU(#@T,B(**E!A<&5R1&EM96YS:6]N($QE9V%L.B`B-C$R(#$P,#@B
M"BI087!E<D1I;65N<VEO;B!,971T97(Z("(V,3(@-SDR(@HJ4&%P97)$:6UE
M;G-I;VX@5&%B;&]I9#H@(C<Y,B`Q,C(T(@HJ26UA9V5A8FQE07)E82!!-#H@
M(C$Q+C,T(#$Q+C,T(#4X,RXV-B`X,S`N-C8B"BI);6%G96%B;&5!<F5A($QE
M9V%L.B`B,3$N,C<@,3$N,S0@-C`P+C<R(#DY-BXW."(**DEM86=E86)L94%R
M96$@3&5T=&5R.B`B,3$N,S,@,3$N,C@@-C`P+C<X(#<X,"XW,B(**DEM86=E
M86)L94%R96$@5&%B;&]I9#H@(C$Q+C(X(#$T+C`@-S@P+C<R(#$R,3(N-S@B
M"@HJ3W)D97)$97!E;F1E;F-Y.B`U,B!!;GE3971U<"`J26YP=713;&]T"BI)
M;G!U=%-L;W0@;6%N=6%L+TUA;G5A;"!F965D("A">7!A<W,@=')A>2DZ("(\
M/"`O5')A>5-W:71C:"!F86QS93X^('-E='!A9V5D979I8V4*("`@(#P\("]-
M86YU86Q&965D('1R=64^/B!S971P86=E9&5V:6-E(@HJ26YP=713;&]T('1R
M87DQ+U1R87D@,3H@(CP\("]4<F%Y4W=I=&-H(&9A;'-E/CX@<V5T<&%G961E
M=FEC90H@("`@/#P@+TUA;G5A;$9E960@9F%L<V4^/B!S971P86=E9&5V:6-E
M"B`@("`\/"`O365D:6%0;W-I=&EO;B`Q(#X^('-E='!A9V5D979I8V4*("`@
M(#P\("]-961I851Y<&4@*%5N<W!E8VEF:65D*2`^/B`@<V5T<&%G961E=FEC
M90H@("`@/#P@+TUE9&EA0V]L;W(@*%5N<W!E8VEF:65D*2`^/B`@<V5T<&%G
M961E=FEC92(**DEN<'5T4VQO="!T<F%Y,B]4<F%Y(#(Z("(\/"`O5')A>5-W
M:71C:"!F86QS93X^('-E='!A9V5D979I8V4*("`@(#P\("]-86YU86Q&965D
M(&9A;'-E/CX@<V5T<&%G961E=FEC90H@("`@/#P@+TUE9&EA4&]S:71I;VX@
M,B`^/B!S971P86=E9&5V:6-E"B`@("`\/"`O365D:6%4>7!E("A5;G-P96-I
M9FEE9"D@/CX@('-E='!A9V5D979I8V4*("`@(#P\("]-961I84-O;&]R("A5
M;G-P96-I9FEE9"D@/CX@('-E='!A9V5D979I8V4B"BI);G!U=%-L;W0@=')A
M>3,O5')A>2`S.B`B/#P@+U1R87E3=VET8V@@9F%L<V4^/B!S971P86=E9&5V
M:6-E"B`@("`\/"`O36%N=6%L1F5E9"!F86QS93X^('-E='!A9V5D979I8V4*
M("`@(#P\("]-961I85!O<VET:6]N(#,@/CX@<V5T<&%G961E=FEC90H@("`@
M/#P@+TUE9&EA5'EP92`H56YS<&5C:69I960I(#X^("!S971P86=E9&5V:6-E
M"B`@("`\/"`O365D:6%#;VQO<B`H56YS<&5C:69I960I(#X^("!S971P86=E
M9&5V:6-E(@HJ26YP=713;&]T('1R87DT+U1R87D@-#H@(CP\("]4<F%Y4W=I
M=&-H(&9A;'-E/CX@<V5T<&%G961E=FEC90H@("`@/#P@+TUA;G5A;$9E960@
M9F%L<V4^/B!S971P86=E9&5V:6-E"B`@("`\/"`O365D:6%0;W-I=&EO;B`T
M(#X^('-E='!A9V5D979I8V4*("`@(#P\("]-961I851Y<&4@*%5N<W!E8VEF
M:65D*2`^/B`@<V5T<&%G961E=FEC90H@("`@/#P@+TUE9&EA0V]L;W(@*%5N
M<W!E8VEF:65D*2`^/B`@<V5T<&%G961E=FEC92(**DEN<'5T4VQO="!T<F%Y
M-2](:6=H(&-A<&%C:71Y(&9E961E<CH@(CP\("]4<F%Y4W=I=&-H(&9A;'-E
M/CX@<V5T<&%G961E=FEC90H@("`@/#P@+TUA;G5A;$9E960@9F%L<V4^/B!S
M971P86=E9&5V:6-E"B`@("`\/"`O365D:6%0;W-I=&EO;B`U(#X^('-E='!A
M9V5D979I8V4*("`@(#P\("]-961I851Y<&4@*%5N<W!E8VEF:65D*2`^/B`@
M<V5T<&%G961E=FEC90H@("`@/#P@+TUE9&EA0V]L;W(@*%5N<W!E8VEF:65D
M*2`^/B`@<V5T<&%G961E=FEC92(*"BI/<F1E<D1E<&5N9&5N8WDZ(#8P($%N
M>5-E='5P("I/=71P=71":6X**D]U='!U=$)I;B!S:61E+U-I9&4@=')A>3H@
M(CP\("]/=71P=714>7!E("A3:61E5')A>2D@/CX@<V5T<&%G961E=FEC92(*
M*D]U='!U=$)I;B!S=&%C:V5R+T9I;FES:&5R.B`B/#P@+T]U='!U=%1Y<&4@
M*%-T86-K97(I(#X^('-E='!A9V5D979I8V4B"BI/=71P=71":6X@=&]P+U1O
M<"!T<F%Y.B`B/#P@+T]U='!U=%1Y<&4@*%1O<%1R87DI(#X^('-E='!A9V5D
M979I8V4B"@HJ3W!T:6]N($U#;W!I97,O375L=&EP;&4@8V]P:65S+"`M3TU#
M;W!I97,](SH@(F-V:0H)/#P@97AC:"`O3G5M0V]P:65S(&5X8V@@+T-O;&QA
M=&4@=')U92`^/B!S971P86=E9&5V:6-E(@H**D]P=&EO;B!3=&%P;&5.;VYE
M+TYO('-T87!L93H@(CP\("]3=&%P;&4@,"`^/B!S971P86=E9&5V:6-E(@HJ
M3W!T:6]N(%-T87!L92]3:6YG;&4@<W1A<&QE.B`B/#P@+T-O;&QA=&4@=')U
M92`O4W1A<&QE(#,@/CX@<V5T<&%G961E=FEC92(*"BHE(%1H92!897)O>"!$
M;V-U;65N="!#96YT<F4@-#,R(&ES(&1E<VEG;F5D(&9O<B!T:&4@4$,@<')I
M;G1I;F<@96YV:7)O;FUE;G0**B4@=VAE<F4@82!P<FEN=&IO8B!C;VYS:7-T
M<R!O9B!A('-I;F=L92!D;V-U;65N="X@5&AE('!R:6YT97(@9&]E<VXG="!H
M879E"BHE(&$@;65T:&]D('1O(&UA<FL@=&AE(&5N9"!O9B!T:&4@8W5R<F5N
M="!D;V-U;65N="!A;F0@=&AE(&)E9VEN;FEN9R!O9B!T:&4**B4@;F5X="!D
M;V-U;65N="P@9F]R(&5X86UP;&4@8W1R;"UD+B!4:&4@<')I;G1E<B!D969I
M;F5S(&$@9&]C=6UE;G0@87,**B4@979E<GET:&EN9R!B971W965N('1H92!S
M=&%R="!A;F0@96YD(&]F(&$@;F5T=V]R:R!C;VYN96-T:6]N+@HJ)2`**B4@
M5&AE('!R:6YT97(G<R!I;F%B:6QI='D@=&\@<')O8V5S<R!M;W)E('1H86X@
M;VYE(&1O8W5M96YT(&EN(&$@<VEN9VQE(&IO8@HJ)2!C86X@8V%U<V4@;75L
M=&EP;&4@<')O8FQE;7,N($]N92!O9B!T:&4@;6]R92!V:7-I8FQE('!R;V)L
M96US(&ES('-T87!L:6YG"BHE('1H92!B86YN97(@<&%G92!O;B!T:&4@9&]C
M=6UE;G0N(%AE<F]X(&AA<R!A('=O<FMA<F]U;F0@=&\@<')E=F5N="!T:&4@
M8F%N;F5R"BHE('!A9V4@8F5I;F<@<W1A<&QE9"!T;R!T:&4@9&]C=6UE;G0@
M8G5T(&ET)W,@:6YT96YD960@9F]R('1H92!00R!E;G9I<F]N;65N="X**B4@
M5&AI<R!W;W)K87)O=6YD(&1O97,@;F]T('1A:V4@:6YT;R!C;VYS:61E<F%T
M:6]N('1H92!U<V5R)W,@86)I;&ET>2!T;R`**B4@<W5P<')E<W,@=&AE(&)A
M;FYE<B!P86=E+"!I93H@;'!R("UH+@HJ)2`**B4@4V]M92!P<FEN=&5R(&9E
M871U<F5S(&%R92!S970@=7-I;F<@)24@8V]M;65N=',@:6X@82`E)5A26&)E
M9VEN("4E6%)896YD"BHE(&-O;6UE;G0@8FQO8VLN(%5N;&EK92!0;W-T4V-R
M:7!T(&-O9&4@=VAE<F4@=&AE(&QA<W0@<V5T=&EN9R!T86ME<R!A9F9E8W0L
M"BHE(&]N;'D@=&AE(&9I<G-T("4E6%)88F5G:6X@8V]M;6%N9"!B;&]C:R!H
M87,@86YY(&5F9F5C="X**B4@"BHE(%1H97)E(&%R92!T=V\@8F%N;F5R('!A
M9V5S+"!T:&4@<')I;G0@9FEL=&5R(&=E;F5R871E9"!B86YN97(@<&%G92!A
M;F0@=&AE"BHE('!R:6YT97(@*&AA<F1W87)E*2!G96YE<F%T960@8F%N;F5R
M('!A9V4N(%1H92`J3W!T:6]N(&-O;6UA;F1S($]&:6YI="!A;F0@"BHE($E&
M:6YI="!W97)E(&-R96%T960@=&\@:&%N9&QE('1H92!V87)I;W5S(&)A;FYE
M<B!P86=E<R!C;VYD:71I;VYS('=H96X@"BHE('-T87!L:6YG(&ES(')E<75E
M<W1E9"X**B4@"BHE($%D9&ET:6]N86P@8V]M;65N=',@<')O=FED960@:6X@
M*DYO=&5S+@H**B4@4')I;G1C87`@3W5T<'5T($9I;'1E<B!O<'1I;VX@*T]/
M1FEN:70**B4@26YF;W)M('1H92!P<FEN=&5R('1H92!P<FEN="!F:6QT97(@
M:7,@8W)E871I;F<@82!B86YN97(@<&%G92X@5&AI<PHJ)2!D:7-A8FQE<R!T
M:&4@<')I;G1E<B!G96YE<F%T960@8F%N;F5R('!A9V4@86YD('!R979E;G1S
M('-T87!L:6YG('1H90HJ)2!P<FEN="!F:6QT97(@9V5N97)A=&5D(&)A;FYE
M<B!P86=E('1O('1H92!D;V-U;65N="X**D]P=&EO;B!/1G-E='5P+U!R:6YT
M8V%P($]&('-T87!L97(@<V5T=7`Z("(E)5A26&)E9VEN"B`@)25/241?0514
M7U-405)47U-(1454(%5315(["B`@)2584EAE;F0B"@HJ)2!0<FEN=&-A<"!)
M;G!U="!&:6QT97(@;W!T:6]N("M/249I;FET"BHE($1I<V%B;&4@=&AE('!R
M:6YT97(@9V5N97)A=&5D(&)A;FYE<B!P86=E+@HJ3W!T:6]N($E&<V5T=7`O
M4')I;G1C87`@248@<W1A<&QE<B!S971U<#H@(B4E6%)88F5G:6X*("`E)4])
M1%]!5%1?4U1!4E1?4TA%150@3D].13L*("`E)5A26&5N9"(**D9O;G0@07)I
M86PM0F]L9$ET86QI8TU4.B`B(@HJ1F]N="!!<FEA;"U";VQD350Z("(B"BI&
M;VYT($%R:6%L+4ET86QI8TU4.B`B(@HJ1F]N="!!<FEA;$U4.B`B(@HJ1F]N
M="!!=F%N=$=A<F1E+4)O;VLZ("(B"BI&;VYT($%V86YT1V%R9&4M0F]O:T]B
M;&EQ=64Z("(B"BI&;VYT($%V86YT1V%R9&4M1&5M:3H@(B(**D9O;G0@079A
M;G1'87)D92U$96UI3V)L:7%U93H@(B(**D9O;G0@0V]U<FEE<CH@(B(**D9O
M;G0@0V]U<FEE<BU";VQD.B`B(@HJ1F]N="!#;W5R:65R+4)O;&1/8FQI<75E
M.B`B(@HJ1F]N="!#;W5R:65R+4]B;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC
M83H@(B(**D9O;G0@2&5L=F5T:6-A+4)O;&0Z("(B"BI&;VYT($AE;'9E=&EC
M82U";VQD3V)L:7%U93H@(B(**D9O;G0@2&5L=F5T:6-A+4-O;F1E;G-E9#H@
M(B(**D9O;G0@2&5L=F5T:6-A+4-O;F1E;G-E9"U";VQD.B`B(@HJ1F]N="!(
M96QV971I8V$M0V]N9&5N<V5D+4)O;&1/8FPZ("(B"BI&;VYT($AE;'9E=&EC
M82U#;VYD96YS960M3V)L:7%U93H@(B(**D9O;G0@2&5L=F5T:6-A+4YA<G)O
M=SH@(B(**D9O;G0@2&5L=F5T:6-A+4YA<G)O=RU";VQD.B`B(@HJ1F]N="!(
M96QV971I8V$M3F%R<F]W+4)O;&1/8FQI<75E.B`B(@HJ1F]N="!(96QV971I
M8V$M3F%R<F]W+4]B;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC82U/8FQI<75E
M.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H;&)K+4)O;&0Z("(B"BI&;VYT($YE
M=T-E;G1U<GE38VAL8FLM0F]L9$ET86QI8SH@(B(**D9O;G0@3F5W0V5N='5R
M>5-C:&QB:RU)=&%L:6,Z("(B"BI&;VYT($YE=T-E;G1U<GE38VAL8FLM4F]M
M86XZ("(B"BI&;VYT(%1I;65S+4)O;&0Z("(B"BI&;VYT(%1I;65S+4)O;&1)
M=&%L:6,Z("(B"BI&;VYT(%1I;65S+4ET86QI8SH@(B(**D9O;G0@5&EM97,M
M4F]M86XZ("(B"BI&;VYT(%1I;65S3F5W4F]M86Y04RU";VQD271A;&EC350Z
M("(B"BI&;VYT(%1I;65S3F5W4F]M86Y04RU";VQD350Z("(B"BI&;VYT(%1I
M;65S3F5W4F]M86Y04RU)=&%L:6--5#H@(B(**D9O;G0@5&EM97-.97=2;VUA
M;E!3350Z("(B"BI&;VYT($5U<F]S=&EL93H@(B(**D9O;G0@175R;W-T:6QE
M+4)O;&0Z("(B"BI&;VYT($5U<F]S=&EL92U";VQD17AT96YD9614=V\Z("(B
M"BI&;VYT($5U<F]S=&EL92U%>'1E;F1E9%1W;SH@(B(**B4@3F]T97,Z(E=H
M96X@=7-I;F<@=&AE('-T87!L92!O<'1I;VX@<W5B;6ET(&]N;'D@;VYE(&9I
M;&4@9F]R('!R:6YT:6YG+B!4:&4**B4@"7-T87!L92!F:6YI<VAI;F<@9F5A
M='5R92!I<R!A<'!L:65D(&)Y(&IO8B!N;W0@8GD@9&]C=6UE;G0N($$@<')I
M;G0**B4@"7-U8FUI="!C;VYT86EN:6YG(&UU;'1I<&QE(&9I;&5S(&ES('-T
M87!L960@87,@82!S:6YG;&4@9&]C=6UE;G0N"BHE("`@("`@("`@"BHE(`E4
M;R!M86ME(&UU;'1I<&QE('-T87!L960@8V]P:65S(&]F(&$@9&]C=6UE;G0@
M=7-E("U/;6-O<&EE<STC+`HJ)2`)=VAE<F4@(R!R97!R97-E;G1S('1H92!N
M=6UB97(@;V8@8V]P:65S+B!4:&4@+4]M8V]P:65S(&]P=&EO;B!I<PHJ)2`)
M;F]T(&-O;7!A=&EB;&4@=VET:"!E87)L:65R('9E<G-I;VYS(&]F('1H92!P
9<&1O9B!P<FEN="!F:6QT97(N(@HJ16YD"F5R
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/ppd/xeroxDC432.rpd 14082 7
fi

backup_file=$(preInstall "1.1.2.1" /usr/lbin/lprsetup/Xerox_Document_Centre_432ST.lpd 53199 1)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/lprsetup/Xerox_Document_Centre_432ST.lpd
M(R!`*",I)%)#4V9I;&4Z(%AE<F]X7T1O8W5M96YT7T-E;G1R95\T,S)35"YL
M<&0L=B`D("12979I<VEO;CH@,2XQ+C(N,2`D("1$871E.B`R,#`R+S`Q+S,Q
M(#$U.C`Q.C(V("0*<')I;G1E<CI<"B`@("`Z4$X]6&5R;W@@1&]C=6UE;G0@
M0V5N=')E(#0S,B!35#I<"B`@("`Z8G(].38P,#I<"B`@("`Z9F,],#$W-S<W
M-SI<"B`@("`Z9G,],#,Z7`H@("`@.FEF/2]U<W(O;&)I;B]P<&1O9B`K3TE&
M<V5T=7`@*T]086=E4VEZ93U,971T97(@*T-X97)O>$1#-#,R+G)P9#I<"B`@
M("`Z;V8]+W5S<B]L8FEN+W!P9&]F("M/3T9S971U<"`K3U!A9V53:7IE/4QE
M='1E<B`K0WAE<F]X1$,T,S(N<G!D.EP*("`@(#IX9CTO=7-R+VQB:6XO>&8Z
M7`H@("`@.FUX/3`Z7`H@("`@.G!L/38V.EP*("`@(#IP=STP.EP*("`@(#IR
M=SUO;CI<"B`@("`Z>&,],#$W-S<W-SI<"B`@("`Z>',],#0T,#`P.EP*("`@
M(#I01#U<;EP*5&AE(%AE<F]X($1O8W5M96YT($-E;G1R92`T,S(@4U0@:7,@
M82`S,B!P<&T@375L=&EF=6YC=&EO;B!$:6=I=&%L(%P*3W5T<'5T($1E=FEC
*92Y<"EQN7&XZ"G5L
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/lprsetup/Xerox_Document_Centre_432ST.lpd 53199 1
fi

mimimumVersionTest V5.1B
if [[ $? = 0 ]] && [[ $FileInstalled > 0 ]]
then
    if [[ -z $(/usr/sbin/lprsetup -c update) ]]
    then
        print "File /etc/lprsetup.dat was backed up then updated."
    fi
fi
exit 0
