#!/usr/bin/ksh
#
# Xerox Document Centre 470 ST
# LPD self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V5.1"
KIT_TYPE=$KIT_LPD
KIT_PRINTER="Xerox Document Centre 470 ST"
KIT_FILES="xeroxDC470.rpd Xerox_Document_Centre_470ST.lpd"

function setupInstructions {
    mimimumVersionTest V5.1B
    if [[ $? != 0 ]]
    then
	print "Use lprsetup(8) to create an /etc/printcap file entry, specifying" >&2
	print "the printer type "ln17". This creates the entry for your new printer." >&2
	print "Then edit the printcap entry and apply the following changes:" >&2
	print "" >&2
	print "	:if=/usr/lbin/ppdof +OPageSize=Letter +IFsetup +CxeroxDC470.rpd:\\" >&2
	print "	:of=/usr/lbin/ppdof +OPageSize=Letter +OFsetup +CxeroxDC470.rpd:\\" >&2
	print "	:pw#0:\\" >&2
    else
	print "Use lprsetup(8) to create a new /etc/printcap file entry. Driver" >&2
	print "updates will not impact the current /etc/printcap entries." >&2
    fi
    print "" >&2
    print "For additional information refer to printcap(4) \c" >&2
    if [[ ! -z `find /usr/man/man8/ -name ppdof\*` ]]
    then
	print "and ppdof(8) man pages." >&2
    else
	print "man page." >&2
    fi
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "1.0" /usr/lbin/ppd/xeroxDC470.rpd 49505 7)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/ppd/xeroxDC470.rpd
M*D9I;&5697)S:6]N.B`B,2XP(@HJ4')O9'5C=#H@(BA897)O>"!$0R`T.3`O
M-#@P+S0W,"\T-C`@4%,S*2(**DUO9&5L3F%M93H@(EAE<F]X($1O8W5M96YT
M($-E;G1R92`T-S`@4U0B"BI04U9E<G-I;VXZ("(H,S`Q,2XQ,#8I(#(S,#`B
M"BI,86YG=6%G94QE=F5L.B`B,R(**E!#1FEL94YA;64Z(")X97)O>$1#-#<P
M+G)P9"(*"BI/<F1E<D1E<&5N9&5N8WDZ(#4P($%N>5-E='5P("I$=7!L97@*
M*D1U<&QE>"!$=7!L97A.;U1U;6)L92]$=7!L97@Z("(\/"`O1'5P;&5X('1R
M=64@+U1U;6)L92!F86QS92`^/B!S971P86=E9&5V:6-E(@HJ1'5P;&5X($1U
M<&QE>%1U;6)L92]$=7!L97@@='5M8FQE.B`B/#P@+T1U<&QE>"!T<G5E("]4
M=6UB;&4@=')U92`^/B!S971P86=E9&5V:6-E(@HJ1'5P;&5X($YO;F4O4VEM
M<&QE>#H@(CP\("]$=7!L97@@9F%L<V4@+U1U;6)L92!F86QS92`^/B!S971P
M86=E9&5V:6-E(@H**D]R9&5R1&5P96YD96YC>3H@-#4@06YY4V5T=7`@*DUE
M9&EA5'EP90HJ365D:6%4>7!E(%!A<&5R+U!L86EN('!A<&5R.B`B/#P@+TUE
M9&EA5'EP92`H4W1A;F1A<F0I(#X^('-E='!A9V5D979I8V4B"BI-961I851Y
M<&4@5')A;G-P87)E;F-Y+U1R86YS<&%R96YC>3H@(CP\("]-961I851Y<&4@
M*%1R86YS<&%R96YC>2D@/CX@<V5T<&%G961E=FEC92(*"BI/<F1E<D1E<&5N
M9&5N8WDZ(#0W($%N>5-E='5P("I086=E4VEZ90HJ4&%G95-I>F4@030O030@
M,C$P('@@,CDW(&UM.B`B/#P@+U!A9V53:7IE(%LU.34@.#0R72`O26UA9VEN
M9T)";W@@;G5L;"`^/B!S971P86=E9&5V:6-E(@HJ4&%G95-I>F4@3&5G86PO
M3&5G86P@."`Q+S(@>"`Q-"!I;CH@(CP\("]086=E4VEZ92!;-C$R(#$P,#A=
M("]);6%G:6YG0D)O>"!N=6QL(#X^('-E='!A9V5D979I8V4B"BI086=E4VEZ
M92!,971T97(O3&5T=&5R(#@@,2\R('@@,3$@:6XZ("(\/"`O4&%G95-I>F4@
M6S8Q,B`W.3)=("]);6%G:6YG0D)O>"!N=6QL(#X^('-E='!A9V5D979I8V4B
M"BI086=E4VEZ92!486)L;VED+U1A8FQO:60@,3$@>"`Q-R!I;CH@(CP\("]0
M86=E4VEZ92!;-SDR(#$R,C1=("]);6%G:6YG0D)O>"!N=6QL(#X^('-E='!A
M9V5D979I8V4B"BI087!E<D1I;65N<VEO;B!!-#H@(C4Y-2`X-#(B"BI087!E
M<D1I;65N<VEO;B!,96=A;#H@(C8Q,B`Q,#`X(@HJ4&%P97)$:6UE;G-I;VX@
M3&5T=&5R.B`B-C$R(#<Y,B(**E!A<&5R1&EM96YS:6]N(%1A8FQO:60Z("(W
M.3(@,3(R-"(**DEM86=E86)L94%R96$@030Z("(P+C`@,"XP(#4Y-2XP(#@T
M,BXP(@HJ26UA9V5A8FQE07)E82!,96=A;#H@(C`N,"`P+C`@-C$R+C`@,3`P
M."XP-B(**DEM86=E86)L94%R96$@3&5T=&5R.B`B,"XP-2`P+C`@-C$R+C`V
M(#<Y,BXP(@HJ26UA9V5A8FQE07)E82!486)L;VED.B`B,"XP(#`N,#4@-SDR
M+C`@,3(R-"XP-B(*"BI/<F1E<D1E<&5N9&5N8WDZ(#0Y($%N>5-E='5P("I)
M;G!U=%-L;W0**DEN<'5T4VQO="!M86YU86PO36%N=6%L(&9E960@*$)Y<&%S
M<R!T<F%Y*3H@(CP\("]-86YU86Q&965D('1R=64@/CX@<V5T<&%G961E=FEC
M90H@("`@/#P@+TUE9&EA4&]S:71I;VX@-2`^/B!S971P86=E9&5V:6-E"B`@
M("`\/"`O365D:6%4>7!E("A5;G-P96-I9FEE9"D@/CX@<V5T<&%G961E=FEC
M90H@("`@/#P@+TUE9&EA0V]L;W(@*%5N<W!E8VEF:65D*2`^/B!S971P86=E
M9&5V:6-E(@HJ26YP=713;&]T('1R87DQ+U1R87D@,3H@(CP\("]-86YU86Q&
M965D(&9A;'-E(#X^('-E='!A9V5D979I8V4*("`@(#P\("]-961I85!O<VET
M:6]N(#$@/CX@<V5T<&%G961E=FEC90H@("`@/#P@+TUE9&EA5'EP92`H56YS
M<&5C:69I960I(#X^('-E='!A9V5D979I8V4*("`@(#P\("]-961I84-O;&]R
M("A5;G-P96-I9FEE9"D@/CX@<V5T<&%G961E=FEC92(**DEN<'5T4VQO="!T
M<F%Y,B]4<F%Y(#(Z("(\/"`O36%N=6%L1F5E9"!F86QS92`^/B!S971P86=E
M9&5V:6-E"B`@("`\/"`O365D:6%0;W-I=&EO;B`R(#X^('-E='!A9V5D979I
M8V4*("`@(#P\("]-961I851Y<&4@*%5N<W!E8VEF:65D*2`^/B!S971P86=E
M9&5V:6-E"B`@("`\/"`O365D:6%#;VQO<B`H56YS<&5C:69I960I(#X^('-E
M='!A9V5D979I8V4B"BI);G!U=%-L;W0@=')A>3,O5')A>2`S.B`B/#P@+TUA
M;G5A;$9E960@9F%L<V4@/CX@<V5T<&%G961E=FEC90H@("`@/#P@+TUE9&EA
M4&]S:71I;VX@,R`^/B!S971P86=E9&5V:6-E"B`@("`\/"`O365D:6%4>7!E
M("A5;G-P96-I9FEE9"D@/CX@<V5T<&%G961E=FEC90H@("`@/#P@+TUE9&EA
M0V]L;W(@*%5N<W!E8VEF:65D*2`^/B!S971P86=E9&5V:6-E(@HJ26YP=713
M;&]T('1R87DT+U1R87D@-#H@(CP\("]-86YU86Q&965D(&9A;'-E(#X^('-E
M='!A9V5D979I8V4*("`@(#P\("]-961I85!O<VET:6]N(#0@/CX@<V5T<&%G
M961E=FEC90H@("`@/#P@+TUE9&EA5'EP92`H56YS<&5C:69I960I(#X^('-E
M='!A9V5D979I8V4*("`@(#P\("]-961I84-O;&]R("A5;G-P96-I9FEE9"D@
M/CX@<V5T<&%G961E=FEC92(**DEN<'5T4VQO="!T<F%Y-B](:6=H(&-A<&%C
M:71Y(&9E961E<CH@(CP\("]-86YU86Q&965D(&9A;'-E(#X^('-E='!A9V5D
M979I8V4*("`@(#P\("]-961I85!O<VET:6]N(#8@/CX@<V5T<&%G961E=FEC
M90H@("`@/#P@+TUE9&EA5'EP92`H56YS<&5C:69I960I(#X^('-E='!A9V5D
M979I8V4*("`@(#P\("]-961I84-O;&]R("A5;G-P96-I9FEE9"D@/CX@<V5T
M<&%G961E=FEC92(*"BI/<F1E<D1E<&5N9&5N8WDZ(#8P($%N>5-E='5P("I/
M=71P=71":6X**D]U='!U=$)I;B!S=&%C:V5R+T-E;G1E<B!S:61E('1R87DZ
M("(\/"`O3W5T<'5T5'EP92`H36%I;E1R87DI(#X^('-E='!A9V5D979I8V4B
M"BI/=71P=71":6X@<VED92]4;W`@<VED92!T<F%Y.B`B/#P@+T]U='!U=%1Y
M<&4@*%1O<%1R87DI(#X^('-E='!A9V5D979I8V4B"@HJ3W!T:6]N($U#;W!I
M97,O375L=&EP;&4@8V]P:65S+"`M3TU#;W!I97,](SH@(F-V:0H)/#P@97AC
M:"`O3G5M0V]P:65S(&5X8V@@+T-O;&QA=&4@=')U92`^/B!S971P86=E9&5V
M:6-E(@H**D]P=&EO;B!3=&%P;&4O4VEN9VQE('-T87!L93H@(CP\("]#;VQL
M871E('1R=64@+U-T87!L92`S("]3=&%P;&5$971A:6QS"B`@("`\/"`O5'EP
M92`Q("]3=&%P;&5,;V-A=&EO;B`H4VEN9VQE4&]R=')A:70I(#X^(#X^('-E
M='!A9V5D979I8V4B"BI/<'1I;VX@4W1A<&QE1'5A;"]$=6%L('-T87!L93H@
M(CP\("]#;VQL871E('1R=64@+U-T87!L92`S("]3=&%P;&5$971A:6QS"B`@
M("`\/"`O5'EP92`Q("]3=&%P;&5,;V-A=&EO;B`H1'5A;$QA;F1S8V%P92D@
M/CX@/CX@<V5T<&%G961E=FEC92(**D]P=&EO;B!3=&%P;&5.;VYE+TYO('-T
M87!L93H@(CP\("]3=&%P;&4@,"`^/B!S971P86=E9&5V:6-E(@H*"BHE(%1H
M92!897)O>"!$;V-U;65N="!#96YT<F4@-#<P(&ES(&1E<VEG;F5D(&9O<B!T
M:&4@4$,@<')I;G1I;F<@96YV:7)O;FUE;G0**B4@=VAE<F4@82!P<FEN=&IO
M8B!C;VYS:7-T<R!O9B!A('-I;F=L92!D;V-U;65N="X@5&AE('!R:6YT97(@
M9&]E<VXG="!H879E"BHE(&$@;65T:&]D('1O(&UA<FL@=&AE(&5N9"!O9B!T
M:&4@8W5R<F5N="!D;V-U;65N="!A;F0@=&AE(&)E9VEN;FEN9R!O9B!T:&4*
M*B4@;F5X="!D;V-U;65N="P@9F]R(&5X86UP;&4@8W1R;"UD+B!4:&4@<')I
M;G1E<B!D969I;F5S(&$@9&]C=6UE;G0@87,**B4@979E<GET:&EN9R!B971W
M965N('1H92!S=&%R="!A;F0@96YD(&]F(&$@;F5T=V]R:R!C;VYN96-T:6]N
M+@HJ)2`**B4@5&AE('!R:6YT97(G<R!I;F%B:6QI='D@=&\@<')O8V5S<R!M
M;W)E('1H86X@;VYE(&1O8W5M96YT(&EN(&$@<VEN9VQE(&IO8@HJ)2!C86X@
M8V%U<V4@;75L=&EP;&4@<')O8FQE;7,N($]N92!O9B!T:&4@;6]R92!V:7-I
M8FQE('!R;V)L96US(&ES('-T87!L:6YG"BHE('1H92!B86YN97(@<&%G92!O
M;B!T:&4@9&]C=6UE;G0N(%AE<F]X(&AA<R!A('=O<FMA<F]U;F0@=&\@<')E
M=F5N="!T:&4@8F%N;F5R"BHE('!A9V4@8F5I;F<@<W1A<&QE9"!T;R!T:&4@
M9&]C=6UE;G0@8G5T(&ET)W,@:6YT96YD960@9F]R('1H92!00R!E;G9I<F]N
M;65N="X**B4@5&AI<R!W;W)K87)O=6YD(&1O97,@;F]T('1A:V4@:6YT;R!C
M;VYS:61E<F%T:6]N('1H92!U<V5R)W,@86)I;&ET>2!T;R`**B4@<W5P<')E
M<W,@=&AE(&)A;FYE<B!P86=E+"!I93H@;'!R("UH+@HJ)2`**B4@4V]M92!P
M<FEN=&5R(&9E871U<F5S(&%R92!S970@=7-I;F<@)24@8V]M;65N=',@:6X@
M82`E)5A26&)E9VEN("4E6%)896YD"BHE(&-O;6UE;G0@8FQO8VLN(%5N;&EK
M92!0;W-T4V-R:7!T(&-O9&4@=VAE<F4@=&AE(&QA<W0@<V5T=&EN9R!T86ME
M<R!A9F9E8W0L"BHE(&]N;'D@=&AE(&9I<G-T("4E6%)88F5G:6X@8V]M;6%N
M9"!B;&]C:R!H87,@86YY(&5F9F5C="X**B4@"BHE(%1H97)E(&%R92!T=V\@
M8F%N;F5R('!A9V5S+"!T:&4@<')I;G0@9FEL=&5R(&=E;F5R871E9"!B86YN
M97(@<&%G92!A;F0@=&AE"BHE('!R:6YT97(@*&AA<F1W87)E*2!G96YE<F%T
M960@8F%N;F5R('!A9V4N(%1H92`J3W!T:6]N(&-O;6UA;F1S($]&:6YI="!A
M;F0@"BHE($E&:6YI="!W97)E(&-R96%T960@=&\@:&%N9&QE('1H92!V87)I
M;W5S(&)A;FYE<B!P86=E<R!C;VYD:71I;VYS('=H96X@"BHE('-T87!L:6YG
M(&ES(')E<75E<W1E9"X**B4@"BHE($%D9&ET:6]N86P@8V]M;65N=',@<')O
M=FED960@:6X@*DYO=&5S+@H**B4@4')I;G1C87`@3W5T<'5T($9I;'1E<B!O
M<'1I;VX@*T]/1FEN:70**B4@26YF;W)M('1H92!P<FEN=&5R('1H92!P<FEN
M="!F:6QT97(@:7,@8W)E871I;F<@82!B86YN97(@<&%G92X@5&AI<R`**B4@
M9&ES86)L97,@=&AE('!R:6YT97(@9V5N97)A=&5D(&)A;FYE<B!P86=E(&%N
M9"!P<F5V96YT<R!S=&%P;&EN9R!T:&4@"BHE('!R:6YT(&9I;'1E<B!G96YE
M<F%T960@8F%N;F5R('!A9V4@=&\@=&AE(&1O8W5M96YT+@HJ3W!T:6]N($]&
M<V5T=7`O4')I;G1C87`@3T8@<W1A<&QE<B!S971U<#H@(B4E6%)88F5G:6X*
M("`E)4])1%]!5%1?4U1!4E1?4TA%150@55-%4CL*("`E)5A26&5N9"(*"BHE
M(%!R:6YT8V%P($EN<'5T($9I;'1E<B!O<'1I;VX@*T])1FEN:70**B4@1&ES
M86)L92!T:&4@<')I;G1E<B!G96YE<F%T960@8F%N;F5R('!A9V4N"BI/<'1I
M;VX@249S971U<"]0<FEN=&-A<"!)1B!S=&%P;&5R('-E='5P.B`B)2584EAB
M96=I;@H@("4E3TE$7T%45%]35$%25%]32$5%5"!.3TY%.PH@("4E6%)896YD
M(@H**D9O;G0@07)I86PM0F]L9$ET86QI8TU4.B`B(@HJ1F]N="!!<FEA;"U"
M;VQD350Z("(B"BI&;VYT($%R:6%L+4ET86QI8TU4.B`B(@HJ1F]N="!!<FEA
M;$U4.B`B(@HJ1F]N="!!=F%N=$=A<F1E+4)O;VLZ("(B"BI&;VYT($%V86YT
M1V%R9&4M0F]O:T]B;&EQ=64Z("(B"BI&;VYT($%V86YT1V%R9&4M1&5M:3H@
M(B(**D9O;G0@079A;G1'87)D92U$96UI3V)L:7%U93H@(B(**D9O;G0@0V]U
M<FEE<CH@(B(**D9O;G0@0V]U<FEE<BU";VQD.B`B(@HJ1F]N="!#;W5R:65R
M+4)O;&1/8FQI<75E.B`B(@HJ1F]N="!#;W5R:65R+4]B;&EQ=64Z("(B"BI&
M;VYT($AE;'9E=&EC83H@(B(**D9O;G0@2&5L=F5T:6-A+4)L86-K.B`B(@HJ
M1F]N="!(96QV971I8V$M0FQA8VM/8FQI<75E.B`B(@HJ1F]N="!(96QV971I
M8V$M0F]L9#H@(B(**D9O;G0@2&5L=F5T:6-A+4)O;&1/8FQI<75E.B`B(@HJ
M1F]N="!(96QV971I8V$M0V]N9&5N<V5D.B`B(@HJ1F]N="!(96QV971I8V$M
M0V]N9&5N<V5D+4)O;&0Z("(B"BI&;VYT($AE;'9E=&EC82U#;VYD96YS960M
M0F]L9$]B;#H@(B(**D9O;G0@2&5L=F5T:6-A+4-O;F1E;G-E9"U/8FQI<75E
M.B`B(@HJ1F]N="!(96QV971I8V$M3&EG:'0Z("(B"BI&;VYT($AE;'9E=&EC
M82U,:6=H=$]B;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC82U.87)R;W<Z("(B
M"BI&;VYT($AE;'9E=&EC82U.87)R;W<M0F]L9#H@(B(**D9O;G0@2&5L=F5T
M:6-A+4YA<G)O=RU";VQD3V)L:7%U93H@(B(**D9O;G0@2&5L=F5T:6-A+4YA
M<G)O=RU/8FQI<75E.B`B(@HJ1F]N="!(96QV971I8V$M3V)L:7%U93H@(B(*
M*D9O;G0@3F5W0V5N='5R>5-C:&QB:RU";VQD.B`B(@HJ1F]N="!.97=#96YT
M=7)Y4V-H;&)K+4)O;&1)=&%L:6,Z("(B"BI&;VYT($YE=T-E;G1U<GE38VAL
M8FLM271A;&EC.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H;&)K+5)O;6%N.B`B
M(@HJ1F]N="!4:6UE<RU";VQD.B`B(@HJ1F]N="!4:6UE<RU";VQD271A;&EC
M.B`B(@HJ1F]N="!4:6UE<RU)=&%L:6,Z("(B"BI&;VYT(%1I;65S+5)O;6%N
M.B`B(@HJ1F]N="!4:6UE<TYE=U)O;6%N4%,M0F]L9$ET86QI8TU4.B`B(@HJ
M1F]N="!4:6UE<TYE=U)O;6%N4%,M0F]L9$U4.B`B(@HJ1F]N="!4:6UE<TYE
M=U)O;6%N4%,M271A;&EC350Z("(B"BI&;VYT(%1I;65S3F5W4F]M86Y04TU4
M.B`B(@HJ1F]N="!%=7)O<W1I;&4Z("(B"BI&;VYT($5U<F]S=&EL92U";VQD
M.B`B(@HJ1F]N="!%=7)O<W1I;&4M0F]L9$5X=&5N9&5D5'=O.B`B(@HJ1F]N
M="!%=7)O<W1I;&4M17AT96YD9614=V\Z("(B"BHE3F]T97,Z(E=H96X@=7-I
M;F<@=&AE('-T87!L92!O<'1I;VX@<W5B;6ET(&]N;'D@;VYE(&9I;&4@9F]R
M('!R:6YT:6YG+B!4:&4**B4)<W1A<&QE(&9I;FES:&EN9R!F96%T=7)E(&ES
M(&%P<&QI960@8GD@:F]B(&YO="!B>2!D;V-U;65N="X@02!P<FEN=`HJ)0ES
M=6)M:70@8V]N=&%I;FEN9R!M=6QT:7!L92!F:6QE<R!I<R!S=&%P;&5D(&%S
M(&$@<VEN9VQE(&1O8W5M96YT+@HJ)2`@(`HJ)2`)5&\@;6%K92!M=6QT:7!L
M92!S=&%P;&5D(&-O<&EE<R!O9B!A(&1O8W5M96YT('5S92`M3VUC;W!I97,]
M(RP**B4@"7=H97)E(",@<F5P<F5S96YT<R!T:&4@;G5M8F5R(&]F(&-O<&EE
M<RX@5&AE("U/;6-O<&EE<R!O<'1I;VX@:7,**B4@"6YO="!C;VUP871I8FQE
M('=I=&@@96%R;&EE<B!V97)S:6]N<R!O9B!T:&4@<'!D;V8@<')I;G0@9FEL
+=&5R+B(**D5N9`IE
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/ppd/xeroxDC470.rpd 49505 7
fi

backup_file=$(preInstall "1.1.2.1" /usr/lbin/lprsetup/Xerox_Document_Centre_470ST.lpd 32720 1)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/lprsetup/Xerox_Document_Centre_470ST.lpd
M(R!`*",I)%)#4V9I;&4Z(%AE<F]X7T1O8W5M96YT7T-E;G1R95\T-S!35"YL
M<&0L=B`D("12979I<VEO;CH@,2XQ+C(N,2`D("1$871E.B`R,#`R+S`Q+S,Q
M(#$U.C`Q.C(W("0*<')I;G1E<CI<"B`@("`Z4$X]6&5R;W@@1&]C=6UE;G0@
M0V5N=')E(#0W,"!35#I<"B`@("`Z8G(].38P,#I<"B`@("`Z9F,],#$W-S<W
M-SI<"B`@("`Z9G,],#,Z7`H@("`@.FEF/2]U<W(O;&)I;B]P<&1O9B`K3TE&
M<V5T=7`@*T]086=E4VEZ93U,971T97(@*T-X97)O>$1#-#<P+G)P9#I<"B`@
M("`Z;V8]+W5S<B]L8FEN+W!P9&]F("M/3T9S971U<"`K3U!A9V53:7IE/4QE
M='1E<B`K0WAE<F]X1$,T-S`N<G!D.EP*("`@(#IX9CTO=7-R+VQB:6XO>&8Z
M7`H@("`@.FUX/3`Z7`H@("`@.G!L/38V.EP*("`@(#IP=STP.EP*("`@(#IR
M=SUO;CI<"B`@("`Z>&,],#$W-S<W-SI<"B`@("`Z>',],#0T,#`P.EP*("`@
M(#I01#U<;EP*5&AE(%AE<F]X($1O8W5M96YT($-E;G1R92`T-S`@4U0@:7,@
M82`V-2!P<&T@375L=&EF=6YC=&EO;B!$:6=I=&%L(%P*3W5T<'5T($1E=FEC
*92Y<"EQN7&XZ"G5L
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/lprsetup/Xerox_Document_Centre_470ST.lpd 32720 1
fi

mimimumVersionTest V5.1B
if [[ $? = 0 ]] && [[ $FileInstalled > 0 ]]
then
    if [[ -z $(/usr/sbin/lprsetup -c update) ]]
    then
        print "File /etc/lprsetup.dat was backed up then updated."
    fi
fi
exit 0
